@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2009-2012, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2009-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -70,7 +70,7 @@ END_EVENT_TABLE()
 // BaseFrame
 
 BaseFrame::BaseFrame(const wxImage &background)
-	: wxFrame(NULL, wxID_ANY, _T("Barry Desktop Control Panel"),
+	: wxFrame(NULL, wxID_ANY, _W("Barry Desktop Control Panel"),
 		wxPoint(50, 50),
 		wxSize(background.GetWidth(), background.GetHeight()),
 		wxMINIMIZE_BOX | wxCAPTION | wxCLOSE_BOX | wxSYSTEM_MENU |
@@ -80,6 +80,7 @@ BaseFrame::BaseFrame(const wxImage &background)
 	, m_height(background.GetHeight())
 	, m_current_mode(0)
 	, m_backup_process(this)
+	, m_rescan_pending(false)
 {
 	// This is a workaround for different size behaviour
 	// in the GTK version of wxWidgets 2.9
@@ -105,15 +106,15 @@ BaseFrame::BaseFrame(const wxImage &background)
 	// Create the Barry Logo popup system menu
 	m_sysmenu.reset( new wxMenu );
 	m_sysmenu->Append( new wxMenuItem(m_sysmenu.get(),
-		SysMenu_VerboseLogging, _T("&Verbose Logging"),
-		_T("Enable low level USB debug output"), wxITEM_CHECK, NULL) );
-	m_sysmenu->Append(SysMenu_RenameDevice, _T("Re&name Device..."));
-	m_sysmenu->Append(SysMenu_ResetDevice, _T("Re&set Device"));
-	m_sysmenu->Append(SysMenu_RescanUsb, _T("&Rescan USB"));
+		SysMenu_VerboseLogging, _W("&Verbose Logging"),
+		_W("Enable low level USB debug output"), wxITEM_CHECK, NULL) );
+	m_sysmenu->Append(SysMenu_RenameDevice, _W("Re&name Device..."));
+	m_sysmenu->Append(SysMenu_ResetDevice, _W("Re&set Device"));
+	m_sysmenu->Append(SysMenu_RescanUsb, _W("&Rescan USB"));
 	m_sysmenu->AppendSeparator();
-	m_sysmenu->Append(SysMenu_About, _T("&About..."));
+	m_sysmenu->Append(SysMenu_About, _W("&About..."));
 	m_sysmenu->AppendSeparator();
-	m_sysmenu->Append(wxID_EXIT, _T("E&xit"));
+	m_sysmenu->Append(wxID_EXIT, _W("E&xit"));
 
 	UpdateMenuState();
 	CreateDeviceCombo(wxGetApp().GetGlobalConfig().GetLastDevice());
@@ -153,7 +154,7 @@ void BaseFrame::CreateDeviceCombo(Barry::Pin pin)
 
 	// if there's more than one device, let the user pick "none"
 	if( results.size() > 1 ) {
-		devices.Add(_T("No device selected"));
+		devices.Add(_W("No device selected"));
 	}
 
 	// add one entry for each device
@@ -170,7 +171,7 @@ void BaseFrame::CreateDeviceCombo(Barry::Pin pin)
 
 	// if nothing is there, be descriptive
 	if( devices.GetCount() == 0 ) {
-		devices.Add(_T("No devices available"));
+		devices.Add(_W("No devices available"));
 	}
 
 	// create the combobox
@@ -205,7 +206,7 @@ void BaseFrame::EnableBackButton(Mode *new_mode)
 	wxSize size(-1, MAIN_HEADER_OFFSET - 5 - 5);
 
 	m_back_button.reset( new wxButton(this, MainMenu_BackButton,
-		_T("Main Menu"), pos, size) );
+		_W("Main Menu"), pos, size) );
 
 	// set the new mode
 	m_current_mode = new_mode;
@@ -244,6 +245,12 @@ void BaseFrame::DisableBackButton()
 	// reset the current mode to main menu and repaint
 	m_current_mode = m_main_menu_mode.get();
 	Refresh(false);
+
+	// if a USB rescan is pending, do it now
+	if( m_rescan_pending ) {
+		wxCommandEvent event;
+		OnRescanUsb(event);
+	}
 }
 
 void BaseFrame::OnSize(wxSizeEvent &event)
@@ -273,7 +280,7 @@ void BaseFrame::OnPaint(wxPaintEvent &event)
 	dc.SetTextBackground( wxColour(0, 0, 0, wxALPHA_TRANSPARENT) );
 
 	long width, height, descent;
-	wxString header = _T("Barry Desktop Control Panel");
+	wxString header = _W("Barry Desktop Control Panel");
 	if( m_current_mode )
 		header = m_current_mode->GetTitleText();
 	dc.GetTextExtent(header, &width, &height, &descent);
@@ -323,12 +330,13 @@ void BaseFrame::OnLeftUp(wxMouseEvent &event)
 void BaseFrame::OnBackupRestore(wxCommandEvent &event)
 {
 	if( m_backup_process.IsAppRunning() ) {
-		wxMessageBox(_T("The Backup program is already running!"),
-			_T("Backup and Restore"), wxOK | wxICON_INFORMATION);
+		wxMessageBox(_W("The Backup program is already running!"),
+			_W("Backup and Restore"), wxOK | wxICON_INFORMATION,
+			this);
 		return;
 	}
 
-	if( !m_backup_process.Run(this, "Backup and Restore", _T("barrybackup")) )
+	if( !m_backup_process.Run(this, _C("Backup and Restore"), _T("barrybackup")) )
 		return;
 }
 
@@ -343,7 +351,7 @@ void BaseFrame::OnSync(wxCommandEvent &event)
 		m_sync_mode.reset( new SyncMode(this) );
 	}
 	catch( std::exception &e ) {
-		wxString msg(_T(
+		wxString msg(_W(
 			"An error occurred that prevented the loading of Sync\n"
 			"mode.  This is most likely because a critical piece\n"
 			"of OpenSync is missing.  Check that all required\n"
@@ -351,7 +359,7 @@ void BaseFrame::OnSync(wxCommandEvent &event)
 			"can find your BlackBerry(R) successfully.\n\n"
 			"Error: "));
 		msg += wxString(e.what(), wxConvUTF8);
-		wxMessageBox(msg, _T("Sync Mode"), wxOK | wxICON_ERROR);
+		wxMessageBox(msg, _W("Sync Mode"), wxOK | wxICON_ERROR, this);
 		return;
 	}
 
@@ -365,8 +373,8 @@ void BaseFrame::OnModem(wxCommandEvent &event)
 		ModemDlg::DoModem(this, pin);
 	}
 	else {
-		wxMessageBox(_T("Please select a device first."),
-			_T("No Device"), wxOK | wxICON_ERROR, this);
+		wxMessageBox(_W("Please select a device first."),
+			_W("No Device"), wxOK | wxICON_ERROR, this);
 	}
 
 /*
@@ -658,7 +666,7 @@ void BaseFrame::OnMigrateDevice(wxCommandEvent &event)
 
 	}
 	catch( std::exception &e ) {
-		wxString msg(_T(
+		wxString msg(_W(
 			"An error occurred during device migration.\n"
 			"This could be due to a low level USB issue\n"
 			"Please make sure your device is plugged in\n"
@@ -667,7 +675,7 @@ void BaseFrame::OnMigrateDevice(wxCommandEvent &event)
 			"\n"
 			"Error: "));
 		msg += wxString(e.what(), wxConvUTF8);
-		wxMessageBox(msg, _T("Migrate Device"), wxOK | wxICON_ERROR);
+		wxMessageBox(msg, _W("Migrate Device"), wxOK | wxICON_ERROR, this);
 		return;
 	}
 }
@@ -676,8 +684,8 @@ void BaseFrame::OnBrowseDatabases(wxCommandEvent &event)
 {
 	int i = Barry::Probe::Find(wxGetApp().GetResults(), GetCurrentComboPin());
 	if( i == -1 ) {
-		wxMessageBox(_T("There is no device selected in the device list.  Please select a device to browse."),
-			_T("Database Browser Mode"), wxOK | wxICON_ERROR);
+		wxMessageBox(_W("There is no device selected in the device list.  Please select a device to browse."),
+			_W("Database Browser Mode"), wxOK | wxICON_ERROR, this);
 		return;
 	}
 
@@ -686,7 +694,7 @@ void BaseFrame::OnBrowseDatabases(wxCommandEvent &event)
 				wxGetApp().GetResults()[i]) );
 	}
 	catch( std::exception &e ) {
-		wxString msg(_T(
+		wxString msg(_W(
 			"An error occurred that prevented the loading of Database\n"
 			"Browse mode.  This could be due to a low level USB\n"
 			"issue.  Please make sure your device is plugged in\n"
@@ -695,7 +703,7 @@ void BaseFrame::OnBrowseDatabases(wxCommandEvent &event)
 			"\n"
 			"Error: "));
 		msg += wxString(e.what(), wxConvUTF8);
-		wxMessageBox(msg, _T("Database Browser Mode"), wxOK | wxICON_ERROR);
+		wxMessageBox(msg, _W("Database Browser Mode"), wxOK | wxICON_ERROR, this);
 		return;
 	}
 
@@ -729,8 +737,16 @@ void BaseFrame::OnTermBackupAndRestore(wxProcessEvent &event)
 	    m_backup_process.GetChildExitCode() &&
 	    (time(NULL) - m_backup_process.GetStartTime()) < 2 )
 	{
-		wxMessageBox(_T("Unable to run barrybackup, or it returned an error. Please make sure it is installed and in your PATH."),
-			_T("Backup and Restore"), wxOK | wxICON_ERROR);
+		wxMessageBox(_W("Unable to run barrybackup, or it returned an error. Please make sure it is installed and in your PATH."),
+			_W("Backup and Restore"), wxOK | wxICON_ERROR, this);
+	}
+	else
+	{
+		// looks like a successful run... the device name may
+		// have been changed by the BarryBackup GUI, so reprobe
+		// to refresh the names and device list
+		wxCommandEvent event;
+		OnRescanUsb(event);
 	}
 }
 
@@ -790,8 +806,8 @@ void BaseFrame::OnRenameDevice(wxCommandEvent &event)
 
 	wxString current_name(results[index].m_cfgDeviceName.c_str(), wxConvUTF8);
 	wxTextEntryDialog dlg(this,
-		_T("Please enter a name for the current device:"),
-		_T("Rename Device"),
+		_W("Please enter a name for the current device:"),
+		_W("Rename Device"),
 		current_name, wxTextEntryDialogStyle);
 
 	if( dlg.ShowModal() != wxID_OK )
@@ -824,20 +840,22 @@ void BaseFrame::OnRescanUsb(wxCommandEvent &event)
 		std::auto_ptr<UsbScanSplash> splash( new UsbScanSplash );
 		wxGetApp().Probe();
 		CreateDeviceCombo(wxGetApp().GetGlobalConfig().GetLastDevice());
+		m_rescan_pending = false;
 	}
 	else {
-		// FIXME - tell the user we didn't do anything?
-		// or perhaps just disable rescan while in a mode
+		// flag that we need to rescan the next time we return
+		// to the main screen
+		m_rescan_pending = true;
 	}
 }
 
 void BaseFrame::OnAbout(wxCommandEvent &event)
 {
 	wxAboutDialogInfo info;
-	info.SetName(_T("Barry Desktop Control Panel"));
+	info.SetName(_W("Barry Desktop Control Panel"));
 	info.SetVersion(_T(BARRY_DESKTOP_VER_STRING));
-	info.SetDescription(_T("A Free Software graphical user interface for working with the BlackBerry® smartphone."));
-	info.SetCopyright(_T("Copyright © 2009-2012, Net Direct Inc."));
+	info.SetDescription(_W("A Free Software graphical user interface for working with the BlackBerry® smartphone."));
+	info.SetCopyright(_T("Copyright © 2009-2013, Net Direct Inc."));
 	info.SetWebSite(_T("http://netdirect.ca/barry"));
 	info.SetLicense(_T(
 "    This program is free software; you can redistribute it and/or modify\n"
@@ -857,9 +875,9 @@ void BaseFrame::OnAbout(wxCommandEvent &event)
 //	info.AddDeveloper(_T("See AUTHORS file for detailed"));
 //	info.AddDeveloper(_T("contribution information."));
 
-	info.AddArtist(_T("Chris Frey - GUI interface"));
-	info.AddArtist(_T("Martin Owens - Barry logo"));
-	info.AddArtist(_T("Tango Desktop Project - Public domain icons"));
+	info.AddArtist(_W("Chris Frey - GUI interface"));
+	info.AddArtist(_W("Martin Owens - Barry logo"));
+	info.AddArtist(_W("Tango Desktop Project - Public domain icons"));
 
 	wxAboutBox(info);
 }
