@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2009-2012, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2009-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ public:
 	virtual ~Mode() {}
 
 	// events (called from BaseFrame)
-	virtual wxString GetTitleText() const { return _T("FIXME"); }
+	virtual wxString GetTitleText() const { return _T("FIXME - Incorrect Mode Title"); }
 	virtual void OnPaint(wxDC &dc) {}
 	virtual void OnMouseMotion(wxDC &dc, int x, int y) {}
 	virtual void OnLeftDown(wxDC &dc, int x, int y) {}
