@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2009-2012, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2009-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include <wx/wx.h>
 #include <memory>
 #include "Mode.h"
+#include "wxi18n.h"
 
 class BaseButtons;
 namespace Barry {
@@ -45,7 +46,7 @@ public:
 	// events (called from BaseFrame)
 	wxString GetTitleText() const
 	{
-		return _T("Barry Desktop Control Panel");
+		return _W("Barry Desktop Control Panel");
 	}
 
 	void OnPaint(wxDC &dc);
