@@ -5,7 +5,7 @@
 ///
 
 /*
-    Copyright (C) 2010-2012, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2010-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include <sstream>
 #include <iomanip>
 #include <iterator>
+#include "wxi18n.h"
 
 using namespace std;
 
@@ -62,7 +63,7 @@ bool StatusConnection::OnPoke(const wxString &topic,
 	}
 	else if( item == STATUS_ITEM_ENTRY ) {
 		m_dlg.Print(msg, *wxBLUE);
-		m_dlg.ShortPrint("Syncing entries...");
+		m_dlg.ShortPrint(_W("Syncing entries..."));
 	}
 	else if( item == STATUS_ITEM_MAPPING ) {
 		m_dlg.Print(msg, *wxBLUE);
@@ -113,8 +114,8 @@ bool ConflictConnection::OnPoke(const wxString &topic,
 				int size,
 				wxIPCFormat format)
 {
-	barryverbose("Conflict::OnPoke: " << topic.utf8_str() << ", "
-		<< item.utf8_str());
+	barryverbose("Conflict::OnPoke: " << string(topic.utf8_str()) << ", "
+		<< string(item.utf8_str()));
 
 	if( topic != TOPIC_CONFLICT )
 		return false;
@@ -254,7 +255,7 @@ END_EVENT_TABLE()
 
 SyncStatusDlg::SyncStatusDlg(wxWindow *parent,
 				const DeviceSet::subset_type &subset)
-	: wxDialog(parent, Dialog_SyncStatus, _T("Device Sync Progress"),
+	: wxDialog(parent, Dialog_SyncStatus, _W("Device Sync Progress"),
 			wxDefaultPosition, wxDefaultSize,
 			wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER)
 	, TermCatcher(this, Dialog_SyncStatus_SyncTerminated)
@@ -302,7 +303,7 @@ void SyncStatusDlg::CreateLayout()
 void SyncStatusDlg::AddStatusSizer(wxSizer *sizer)
 {
 	wxSizer *ss = new wxStaticBoxSizer(
-		new wxStaticBox(this, wxID_ANY, _T("Sync Progress")),
+		new wxStaticBox(this, wxID_ANY, _W("Sync Progress")),
 		wxVERTICAL
 		);
 
@@ -336,7 +337,7 @@ void SyncStatusDlg::AddButtonSizer(wxSizer *sizer)
 	button->Add(
 		m_details_button = new wxButton(this,
 			Dialog_SyncStatus_ShowDetailsButton,
-			_T("Show Details")),
+			_W("Show Details")),
 		0, wxALL, 3);
 
 	button->Add( -1, -1, 1 );
@@ -345,18 +346,18 @@ void SyncStatusDlg::AddButtonSizer(wxSizer *sizer)
 		button->Add(
 			m_runapp_button = new wxButton(this,
 				Dialog_SyncStatus_RunAppButton,
-				_T("Run App")),
+				_W("Run App")),
 			0, wxALL, 3);
 	}
 	button->Add(
 		m_syncagain_button = new wxButton(this,
 			Dialog_SyncStatus_SyncAgainButton,
-			_T("Sync Again")),
+			_W("Sync Again")),
 		0, wxALL, 3);
 	button->Add(
 		m_killclose_button = new wxButton(this,
 			Dialog_SyncStatus_KillCloseButton,
-			_T("Kill Sync")),
+			_W("Kill Sync")),
 		0, wxALL, 3);
 
 	sizer->Add(button, 0, wxALL | wxEXPAND, 5);
@@ -367,7 +368,7 @@ void SyncStatusDlg::SetRunning()
 	if( m_runapp_button )
 		m_runapp_button->Enable(false);
 	m_syncagain_button->Enable(false);
-	m_killclose_button->SetLabel(_T("Kill Sync"));
+	m_killclose_button->SetLabel(_W("Kill Sync"));
 	m_killclose_button->Enable(true);
 	UpdateTitle();
 
@@ -381,7 +382,7 @@ void SyncStatusDlg::SetClose()
 	if( m_runapp_button )
 		m_runapp_button->Enable(true);
 	m_syncagain_button->Enable(true);
-	m_killclose_button->SetLabel(_T("Close"));
+	m_killclose_button->SetLabel(_W("Close"));
 	m_killclose_button->Enable(true);
 	UpdateTitle();
 
@@ -390,7 +391,7 @@ void SyncStatusDlg::SetClose()
 	StopTimer();
 }
 
-void SyncStatusDlg::Print(const std::string &msg, const wxColour &colour)
+void SyncStatusDlg::PrintStd(const std::string &msg, const wxColour &colour)
 {
 	Print(wxString(msg.c_str(), wxConvUTF8), colour);
 }
@@ -401,7 +402,7 @@ void SyncStatusDlg::Print(const wxString &msg, const wxColour &colour)
 	m_status_edit->AppendText(_T("\n") + msg);
 }
 
-void SyncStatusDlg::ShortPrint(const std::string &msg)
+void SyncStatusDlg::ShortPrintStd(const std::string &msg)
 {
 	ShortPrint(wxString(msg.c_str(), wxConvUTF8));
 }
@@ -436,12 +437,12 @@ DeviceEntry* SyncStatusDlg::GetCurrentDevice()
 void SyncStatusDlg::UpdateTitle()
 {
 	if( m_next_device == m_subset.end() ) {
-		SetTitle(_T("Sync Progress Dialog"));
+		SetTitle(_W("Sync Progress Dialog"));
 	}
 	else {
 		ostringstream oss;
-		oss << "Syncing: " << (*m_next_device)->GetPin().Str()
-		    << " with " << (*m_next_device)->GetAppNames();
+		oss << _C("Syncing: ") << (*m_next_device)->GetPin().Str()
+		    << _C(" with ") << (*m_next_device)->GetAppNames();
 		wxString label(oss.str().c_str(), wxConvUTF8);
 		SetTitle(label);
 	}
@@ -476,7 +477,7 @@ void SyncStatusDlg::StartNextSync()
 
 	// anything to do?
 	if( m_next_device == m_subset.end() ) {
-		Print("No more devices to sync.", *wxBLACK);
+		Print(_W("No more devices to sync."), *wxBLACK);
 		SetClose();
 		return;
 	}
@@ -491,8 +492,8 @@ void SyncStatusDlg::StartNextSync()
 	m_device_id = device.GetPin().Str() + " (" + device.GetDeviceName() + ")";
 
 	if( !device.IsConfigured() ) {
-		Print(m_device_id + " is not configured, skipping.", *wxRED);
-		ShortPrint("Skipping unconfigured: " + m_device_id);
+		PrintStd(m_device_id + _C(" is not configured, skipping."), *wxRED);
+		ShortPrintStd(_C("Skipping unconfigured: ") + m_device_id);
 		++m_next_device;
 		m_current_device = m_subset.end();
 		StartNextSync();
@@ -503,9 +504,9 @@ void SyncStatusDlg::StartNextSync()
 	OpenSync::Config::Group *group = device.GetConfigGroup();
 	string group_name = group->GetGroupName();
 
-	string statusmsg = "Starting sync for: " + m_device_id;
-	Print(statusmsg, *wxBLACK);
-	ShortPrint(statusmsg);
+	string statusmsg = _C("Starting sync for: ") + m_device_id;
+	PrintStd(statusmsg, *wxBLACK);
+	ShortPrintStd(statusmsg);
 
 	// for each plugin / app, perform the pre-sync steps
 	for( OpenSync::Config::Group::iterator i = group->begin();
@@ -520,7 +521,7 @@ void SyncStatusDlg::StartNextSync()
 
 	// initialize sync jail process
 	if( m_jailexec.IsAppRunning() ) {
-		string msg = "ERROR: App running in StartNextSync()";
+		wxString msg(_W("ERROR: App running in StartNextSync()"));
 		Print(msg, *wxRED);
 		ShortPrint(msg);
 		SetClose();
@@ -541,8 +542,8 @@ void SyncStatusDlg::StartNextSync()
 	command += wxString(sync_code.str().c_str(), wxConvUTF8);
 
 	if( !m_jailexec.Run(NULL, "bsyncjail", command) ) {
-		Print("ERROR: unable to start bsyncjail: " + string(command.utf8_str()), *wxRED);
-		ShortPrint("ERROR: unable to start bsyncjail");
+		Print(_W("ERROR: unable to start bsyncjail: ") + command, *wxRED);
+		ShortPrint(_W("ERROR: unable to start bsyncjail"));
 		SetClose();
 		return;
 	}
@@ -553,11 +554,11 @@ void SyncStatusDlg::StartNextSync()
 
 void SyncStatusDlg::OnSlowSync()
 {
-	Print("Slow sync detected!  Killing sync automatically.", *wxRED);
+	Print(_W("Slow sync detected!  Killing sync automatically."), *wxRED);
 	KillSync();
 
-	Print("Slow syncs are known to be unreliable.", *wxBLACK);
-	Print("Do a 1 Way Reset, and sync again.", *wxBLACK);
+	Print(_W("Slow syncs are known to be unreliable."), *wxBLACK);
+	Print(_W("Do a 1 Way Reset, and sync again."), *wxBLACK);
 }
 
 void SyncStatusDlg::OnInitDialog(wxInitDialogEvent &event)
@@ -572,8 +573,8 @@ void SyncStatusDlg::OnRunApp(wxCommandEvent &event)
 		return;
 
 	if( m_ui.get() && m_ui->IsAppRunning() ) {
-		wxMessageBox(_T("The application is already running."),
-			_T("Run Application"), wxOK | wxICON_ERROR);
+		wxMessageBox(_W("The application is already running."),
+			_W("Run Application"), wxOK | wxICON_ERROR, this);
 		return;
 	}
 
@@ -599,21 +600,19 @@ void SyncStatusDlg::OnKillClose(wxCommandEvent &event)
 	if( m_jailexec.IsAppRunning() ) {
 		int choice;
 		if( m_killingjail ) {
-			choice = wxMessageBox(_T("Already killing sync.  Kill again?"),
-				_T("Kill Sync"), wxYES_NO | wxICON_QUESTION);
+			choice = wxMessageBox(_W("Already killing sync.  Kill again?"),
+				_W("Kill Sync"), wxYES_NO | wxICON_QUESTION, this);
 		}
 		else {
-			choice = wxMessageBox(_T("This will kill the syncing child process, and will likely require a configuration reset.\n\nKill sync process anyway?"),
-				_T("Kill Sync"), wxYES_NO | wxICON_QUESTION);
+			choice = wxMessageBox(_W("This will kill the syncing child process, and will likely require a configuration reset.\n\nKill sync process anyway?"),
+				_W("Kill Sync"), wxYES_NO | wxICON_QUESTION, this);
 		}
 
 		if( choice == wxYES ) {
 			KillSync();
 
-			// print a warning so the user know's what's going on
-			Print("Killing sync... this may take a little while...", *wxRED);
-			Print("Remember to re-plug your device.", *wxRED);
-
+			Print(_W("Killing sync... this may take a little while..."), *wxRED);
+			Print(_W("Remember to re-plug your device."), *wxRED);
 			// let the terminate call clean up the buttons
 			return;
 		}
@@ -627,7 +626,7 @@ void SyncStatusDlg::OnShowDetails(wxCommandEvent &event)
 {
 	if( m_status_edit->IsShown() ) {
 		m_status_edit->Hide();
-		m_details_button->SetLabel(_T("Show Details"));
+		m_details_button->SetLabel(_W("Show Details"));
 	}
 	else {
 		if( !m_repositioned ) {
@@ -649,7 +648,7 @@ void SyncStatusDlg::OnShowDetails(wxCommandEvent &event)
 		}
 
 		m_status_edit->Show();
-		m_details_button->SetLabel(_T("Hide Details"));
+		m_details_button->SetLabel(_W("Hide Details"));
 	}
 	m_topsizer->Fit(this);
 }
@@ -673,14 +672,14 @@ void SyncStatusDlg::OnExecTerminated(wxProcessEvent &event)
 {
 	ostringstream oss;
 	if( m_killingjail )
-		oss << "Sync terminated: ";
+		oss << _C("Sync terminated: ");
 	else
-		oss << "Sync finished: ";
+		oss << _C("Sync finished: ");
 	oss << m_device_id;
 	if( m_jailexec.GetChildExitCode() )
-		oss << " with error " << m_jailexec.GetChildExitCode();
-	Print(oss.str(), *wxBLACK);
-	ShortPrint(oss.str());
+		oss << _C(" with error code ") << m_jailexec.GetChildExitCode();
+	PrintStd(oss.str(), *wxBLACK);
+	ShortPrintStd(oss.str());
 	UpdateLastSyncTime();
 
 	m_current_device = m_subset.end();
