@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2011-2012, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2011-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 
 #include "EvoSources.h"
 #include <iostream>
+#include "i18n.h"
 
 using namespace std;
 
@@ -37,14 +38,27 @@ void DumpItems(const EvoSources::List &list)
 
 int main()
 {
+	setlocale(LC_ALL, "");
+	INIT_I18N();
+
+	const char *separator = "\n-----------------------------------------\n";
+
 	EvoSources es;
-	cout << "\nAddressbook:\n------------\n";
+	cout << _C("Defaultable: ") << (es.IsDefaultable() ?
+					_C("Yes") : _C("No")) << endl;
+	cout << _C("Error during detect: ")
+		<< (es.GetErrorMsg().size() ?
+			es.GetErrorMsg().c_str() : _C("(none)"))
+		<< endl;
+	cout << _C("Results:") << "\n";
+
+	cout << "\n" << _C("Addressbook:") << separator;
 	DumpItems(es.GetAddressBook());
-	cout << "\nEvents:\n-------\n";
+	cout << "\n" << _C("Events:") << separator;
 	DumpItems(es.GetEvents());
-	cout << "\nTasks:\n------\n";
+	cout << "\n" << _C("Tasks:") << separator;
 	DumpItems(es.GetTasks());
-	cout << "\nMemos:\n------\n";
+	cout << "\n" << _C("Memos:") << separator;
 	DumpItems(es.GetMemos());
 }
 
