@@ -10,12 +10,10 @@ detailed information on the software that Barry needs.</p>
 
 <? createSubHeader("Getting the Source"); ?>
 
-<p>There are 3 ways to get the source code:
+<p>There are 2 ways to get the source code:
 <ul>
 	<li>download the release tarball from the
-		<a href="http://sourceforge.net/project/showfiles.php?group_id=153722">download page</a></li>
-	<li>download the development tree
-		<a href="http://sourceforge.net/cvs/?group_id=153722">using CVS</a></li>
+		<a href="http://sourceforge.net/projects/barry/files/barry/">download page</a></li>
 	<li>download the development tree
 		<a href="http://repo.or.cz/w/barry.git">using git</a></li>
 </ul>
@@ -24,53 +22,10 @@ detailed information on the software that Barry needs.</p>
 
 <? createSubHeader("Using The Tarball Release"); ?>
 
-<p>There are multiple source packages available on the Sourceforge download page.
-The main tarball is always the tar.bz2 package.  This contains everything in
-CVS, including pre-built configure scripts and website documentation.</p>
-
-<p>As an alternative, the tar.gz packages are Debian-specific.  This comes as
-an "orig" tarball, with the debian/ subdirectory contained in the diff.gz file.
-A .dsc file is included as well, for ease of Debian package building.  These
-files can be expanded into a Debian style source tree with the following
-command, for example:
-<pre>
-	dpkg-source -x barry_0.15-0.dsc
-</pre>
-</p>
-
-<p>Once the tar.gz and diff.gz files are combined, you will have a tree
-identical to what comes with the tar.bz2 package.</p>
-
-<p>See <i>Building the Source</i> below for instructions on building the
-resulting tree.</p>
-
-<p>Alternatively, there are rpm source packages, in the form of src.rpm files.
-These packages can be installed and built as usual, using the rpm and rpmbuild
-commands.</p>
-
-
-<? createSubHeader("Using CVS"); ?>
-
-<p>Up to date instructions for connecting to Sourceforge CVS repositories
-are available on the
-<a href="http://sourceforge.net/cvs/?group_id=153722">CVS page</a>.  This
-usually involves commands like this:
-
-<pre>
-	cvs -d:pserver:anonymous@barry.cvs.sourceforge.net:/cvsroot/barry login
-	(press enter when it asks for password)
-	cvs -d:pserver:anonymous@barry.cvs.sourceforge.net:/cvsroot/barry co -P barry
-</pre>
-</p>
-
-<p>This will place the Barry sources in the barry directory.  To update
-your source tree periodically, do the following:
-<pre>
-	cd barry
-	./buildgen.sh cleanall      (optional)
-	cvs update -Pd
-</pre>
-</p>
+<p>There are multiple source packages available on the Sourceforge download
+page.  The main tarball is always the tar.bz2 package.  This contains
+everything in git, as well as pre-built configure scripts and pre-generated
+HTML documentation.</p>
 
 
 <? createSubHeader("Using git"); ?>
@@ -97,9 +52,7 @@ your source tree periodically, do the following:
 
 
 
-
-
-<? createSubHeader("Preparing Development Sources for Configure"); ?>
+<? createSubHeader("Preparing Git Sources for Configure"); ?>
 
 <p>If you're using a development tree, you'll need to build the usual
 ./configure script before you can proceed.  To do this, you will need
@@ -115,7 +68,6 @@ Barry tree.
 
 
 
-
 <? createSubHeader("Building the Source"); ?>
 
 <p>At this point, or if you are using a source tarball, building Barry
@@ -127,21 +79,25 @@ is a matter of the common set of commands:
 </pre>
 </p>
 
-<p> The top level configure script has two sub-package options:
+<p> The top level configure script also has a number of additional
+sub-package options:
 <ul>
-	<li> --enable-gui </li>
-	<li> --enable-opensync-plugin </li>
+	<li><b>--enable-gui</b> - compile the Barry Backup GUI</li>
+	<li><b>--enable-desktop</b> - compile the Barry Desktop GUI</li>
+	<li><b>--enable-opensync-plugin</b> - compile the Barry plugin for
+		OpenSync 0.2x</li>
+	<li><b>--enable-opensync-plugin-4x</b> - compile the Barry plugin for
+		OpenSync 0.39/0.4x</li>
+	<li><b>--enable-boost</b> - include Boost support in the btool
+		utility</li>
+	<li><b>--enable-rpathhack</b> - if specified, uses a libtool hack to
+		disable rpath during the build</li>
 </ul>
 </p>
 
-<p>Each option will recurse into the gui/ (Backup application) and
-opensync-plugin/ directories respectively, and build the subprojects
-located there automatically.  Make sure you have the needed software
-dependencies installed beforehand.</p>
-
 <p> If you want to generate doxygen documentation, run 'doxygen' from
 the root source directory.  The resulting files will be in
-doc/www/doxygen/html/.  Doxygen 1.5.6 has been used to do this,
+doc/www/doxygen/html/.  Doxygen 1.7.1 has been used to do this,
 but presumably more recent versions will work as well.</p>
 
 
@@ -152,9 +108,10 @@ but presumably more recent versions will work as well.</p>
 btool:
 <pre>
 	cd barry
-	./buildgen.sh cleanall         (this will make a pristine tree)
+	./buildgen.sh cleanall         (start with a fresh tree)
 	./buildgen.sh                  (this creates configure)
-	./configure --enable-boost --enable-gui --enable-opensync-plugin
+	./configure --enable-boost --enable-gui --enable-opensync-plugin \
+		--enable-opensync-plugin-4x --enable-desktop
 	make
 	make install
 	doxygen
@@ -162,14 +119,11 @@ btool:
 
 <p>This will give you a set of command line tools (bcharge, btool, breset,
 bidentify, bjavaloader, pppob), as well as the backup GUI (barrybackup),
-and will install the opensync plugin into the system directory for opensync
-plugins (usually /usr/lib/opensync/plugins).  Available man pages are also
+the Desktop GUI (barrydesktop), and will install the opensync plugins
+into the system directory for opensync plugins (usually
+/usr/lib/opensync/plugins).  Available man pages are also
 installed.</p>
 
-<p>You can use 'btool' to explore your device from the command line.
-Use the -h switch for help on its command line options.  Some good ones to
-start with are <code>-l</code> to list the devices found, and <code>-t</code>
-to list the Database Database.</p>
 
 
 <? createSubHeader("Configure udev to Run bcharge Automatically"); ?>
@@ -197,7 +151,8 @@ your 10-blackberry.rules file to match.</p>
 <p>The source tree comes with sample PPP chat scripts for using your
 Blackberry as a modem.  These sample scripts are located under ppp/ in
 your source directory.
-The binary packages install all the ppp options files under /etc/ppp/peers/
+
+<p>The binary packages install all the ppp options files under /etc/ppp/peers/
 and all the chat scripts (with the *.chat extensions) under
 /etc/chatscripts/.  These directories are important, since the pppd
 program expects to find options files under peers/ and the options files
@@ -214,15 +169,14 @@ files.  The files assume that pppob is located in /usr/sbin/pppob.</p>
 information on using your Blackberry as a modem.</p>
 
 
-<? createSubHeader("Building Barry RPMs from CVS"); ?>
+<? createSubHeader("Building Barry RPMs from git"); ?>
 
 <p> Paul Dugas reports on the mailing list that he uses the following
-steps for building RPMs from CVS:</p>
+steps for building RPMs from git:</p>
 
 <pre>
 	$ cd ~/work
-	$ cvs ... login
-	$ cvs ... co barry
+	$ git clone...
 	$ cd barry
 	$ ./buildgen.sh
 	$ ./configure --enable-gui --enable-opensync-plugin
@@ -235,6 +189,10 @@ steps for building RPMs from CVS:</p>
 	root.  The resulting RPMs end up in ~/.rpmbuild/RPMS/x86_64.
 </pre>
 
+<p> On an RPM based system, install <b>rpm-build</b> and <b>rpmdevtools</b>,
+then run <b>rpmdev-setuptree</b> to create an "rpmbuild" directory in your
+home directory. </p>
+
 
 <? createSubHeader("Building Barry DEBs from Source"); ?>
 
@@ -247,3 +205,14 @@ following:
 </pre>
 </p>
 
+<p>There are manual sub-targets in the debian/rules makefile to build
+binary packages for the OpenSync plugins, which you can invoke as follows:
+<pre>
+	fakeroot -- debian/rules binary os22-binary
+
+	or
+
+	fakeroot -- debian/rules binary os22-binary
+</pre>
+</p>
+
