@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2007-2009, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2007-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 
 #include <gtkmm.h>
 #include <memory>
-#include "ConfigFile.h"
+#include <barry/barry.h>
 
 namespace Barry {
 	class DatabaseDatabase;
@@ -42,22 +42,24 @@ class ConfigDlg
 	Gtk::FileChooserButton *m_pBackupPath;
 
 	// config data
-	ConfigFile::DBListType m_backupList;
-	ConfigFile::DBListType m_restoreList;
+	Barry::ConfigFile::DBListType m_backupList;
+	Barry::ConfigFile::DBListType m_restoreList;
 	std::string m_deviceName;
 	std::string m_backupPath;
 	bool m_promptBackupLabel;
+	bool m_autoSelectAll;
 
 public:
 	ConfigDlg(const Barry::DatabaseDatabase &dbdb,
-		const ConfigFile &config);
+		const Barry::ConfigFile &config);
 	~ConfigDlg();
 
-	const ConfigFile::DBListType& GetBackupList() const { return m_backupList; }
-	const ConfigFile::DBListType& GetRestoreList() const { return m_restoreList; }
+	const Barry::ConfigFile::DBListType& GetBackupList() const { return m_backupList; }
+	const Barry::ConfigFile::DBListType& GetRestoreList() const { return m_restoreList; }
 	const std::string& GetDeviceName() const { return m_deviceName; }
 	const std::string& GetBackupPath() const { return m_backupPath; }
 	bool GetPromptBackupLabel() const { return m_promptBackupLabel; }
+	bool GetAutoSelectAll() const { return m_autoSelectAll; }
 
 	int run();
 
