@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 
 if [ -n "$1" ] ; then
 	echo
@@ -23,7 +23,9 @@ fi
 (cd doc/www && ./static.sh)
 
 # Generate doxygen docs
-(doxygen && rm -f doxygen.log)
+# These are large... let the user run if needed,
+# and post on the website instead of in the tarball.
+#(doxygen && rm -f doxygen.log)
 
 # Generate configure scripts
 ./buildgen.sh
@@ -33,5 +35,6 @@ rm -rf \
 	autom4te.cache \
 	gui/autom4te.cache \
 	opensync-plugin/autom4te.cache \
-	opensync-plugin-0.4x/autom4te.cache
+	opensync-plugin-0.4x/autom4te.cache \
+	desktop/autom4te.cache
 
