@@ -36,7 +36,7 @@ commands.
 \fBbarry\fP is a program that...
 .SH OPTIONS
 These programs follow the usual GNU command line syntax, with long
-options starting with two dashes (`-').
+options starting with two dashes (`\-').
 A summary of options is included below.
 For a complete description, see the Info files.
 .TP
