@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2006-2012, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2006-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include <string.h>
 #include <sstream>
 #include <ctype.h>
+#include "i18n.h"
 
 using namespace Barry::Sync;
 
@@ -70,7 +71,7 @@ bool VCardConverter::ParseData(const char *data)
 
 	}
 	catch( Barry::ConvertError &ce ) {
-		trace.logf("ERROR: vcard:Barry::ConvertError exception: %s", ce.what());
+		trace.logf(_("ERROR: vcard:Barry::ConvertError exception: %s"), ce.what());
 		m_last_errmsg = ce.what();
 		return false;
 	}
@@ -97,7 +98,7 @@ void VCardConverter::operator()(const Barry::Contact &rec)
 
 	}
 	catch( Barry::ConvertError &ce ) {
-		trace.logf("ERROR: vcard:Barry::ConvertError exception: %s", ce.what());
+		trace.logf(_("ERROR: vcard:Barry::ConvertError exception: %s"), ce.what());
 		m_last_errmsg = ce.what();
 	}
 }
@@ -143,7 +144,7 @@ bool VCardConverter::CommitRecordData(BarryEnvironment *env, unsigned int dbId,
 			newRecordId = recordId;
 		}
 		else {
-			trace.log("Can't use recommended recordId, generating new one.");
+			trace.log(_("Can't use recommended recordId, generating new one."));
 			newRecordId = env->m_ContactsSync.m_Table.MakeNewRecordId();
 		}
 	}
@@ -155,9 +156,10 @@ bool VCardConverter::CommitRecordData(BarryEnvironment *env, unsigned int dbId,
 	VCardConverter convert(newRecordId);
 	if( !convert.ParseData(data) ) {
 		std::ostringstream oss;
-		oss << "unable to parse change data for new RecordId: "
+		oss << _("unable to parse change data for new RecordId: ")
 		    << newRecordId
-		    << " (" << convert.GetLastError() << ") data: " << data;
+		    << " (" << convert.GetLastError() << ") "
+		    << _("data: ") << data;
 		errmsg = oss.str();
 		trace.log(errmsg.c_str());
 		return false;
@@ -166,13 +168,13 @@ bool VCardConverter::CommitRecordData(BarryEnvironment *env, unsigned int dbId,
 	Barry::RecordBuilder<Barry::Contact, VCardConverter> builder(convert);
 
 	if( add ) {
-		trace.log("adding record");
+		trace.log(_("adding record"));
 		env->GetDesktop()->AddRecord(dbId, builder);
 	}
 	else {
-		trace.log("setting record");
+		trace.log(_("setting record"));
 		env->GetDesktop()->SetRecord(dbId, StateIndex, builder);
-		trace.log("clearing dirty flag");
+		trace.log(_("clearing dirty flag"));
 		env->GetDesktop()->ClearDirty(dbId, StateIndex);
 	}
 
