@@ -4,7 +4,7 @@
 //
 
 /*
-    Copyright (C) 2006-2009, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2006-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,7 +27,10 @@
 #include <sstream>
 #include <iomanip>
 #include <string.h>
+#include <unistd.h>
+#include "i18n.h"
 
+using namespace Barry;
 
 //////////////////////////////////////////////////////////////////////////////
 // DatabaseSyncState
@@ -141,7 +144,7 @@ unsigned long DatabaseSyncState::GetMappedRecordId(const std::string &uid)
 	// if already in map, use the matching rid
 	idmap::const_iterator it;
 	if( m_IdMap.UidExists(uid, &it) ) {
-		trace.logf("found existing uid in map: %lu", it->second);
+		trace.logf(_("found existing uid in map: %lu"), it->second);
 		return it->second;
 	}
 
@@ -152,7 +155,7 @@ unsigned long DatabaseSyncState::GetMappedRecordId(const std::string &uid)
 		if( m_IdMap.Map(uid, RecordId) != m_IdMap.end() )
 			return RecordId;
 
-		trace.logf("parsed uid already exists in map, skipping");
+		trace.logf(_("parsed uid already exists in map, skipping"));
 	}
 
 	// create one of our own, if we get here...
@@ -161,7 +164,7 @@ unsigned long DatabaseSyncState::GetMappedRecordId(const std::string &uid)
 		RecordId = m_Table.MakeNewRecordId();
 	} while( m_IdMap.Map(uid, RecordId) == m_IdMap.end() );
 
-	trace.logf("made new record id: %lu", RecordId);
+	trace.logf(_("made new record id: %lu"), RecordId);
 	return RecordId;
 }
 
@@ -174,10 +177,6 @@ BarryEnvironment::BarryEnvironment(OSyncMember *pm)
 	: member(pm),
 	m_pin(-1),
 	m_DebugMode(false),
-	m_password(""),
-	m_IConverter("UTF-8"),
-	m_pCon(0),
-	m_pDesktop(0),
 	m_CalendarSync(pm, "calendar"),
 	m_ContactsSync(pm, "contacts")
 {
@@ -185,61 +184,48 @@ BarryEnvironment::BarryEnvironment(OSyncMember *pm)
 
 BarryEnvironment::~BarryEnvironment()
 {
-	delete m_pDesktop;
-	delete m_pCon;
 }
 
 void BarryEnvironment::DoConnect()
 {
-	// Create controller
-	m_pCon = new Barry::Controller(m_ProbeResult);
-	m_pDesktop = new Barry::Mode::Desktop(*m_pCon, m_IConverter);
-	m_pDesktop->Open(m_password.c_str());
+	if( !m_con.get() )
+		throw std::logic_error(_("Tried to use empty Connector"));
+
+	m_con->Connect();
 
 	// Save the DBIDs and DBNames of the databases we will work with
-	m_CalendarSync.m_dbName = Barry::Calendar::GetDBName();
-	m_CalendarSync.m_dbId = m_pDesktop->GetDBID(Barry::Calendar::GetDBName());
+	if( m_CalendarSync.m_Sync ) {
+		m_CalendarSync.m_dbName = Barry::Calendar::GetDBName();
+		m_CalendarSync.m_dbId = m_con->GetDesktop().GetDBID(Barry::Calendar::GetDBName());
+	}
 
-	m_ContactsSync.m_dbId = m_pDesktop->GetDBID(Barry::Contact::GetDBName());
-	m_ContactsSync.m_dbName = Barry::Contact::GetDBName();
+	if( m_ContactsSync.m_Sync ) {
+		m_ContactsSync.m_dbId = m_con->GetDesktop().GetDBID(Barry::Contact::GetDBName());
+		m_ContactsSync.m_dbName = Barry::Contact::GetDBName();
+	}
+}
+
+void BarryEnvironment::SetPassword(const std::string &password)
+{
+	m_password = password;
+	if( m_con.get() )
+		m_con->SetPassword(password.c_str());
 }
 
 void BarryEnvironment::Connect(const Barry::ProbeResult &result)
 {
-	Disconnect();
-
-	// save result in case we need to reconnect later
-	m_ProbeResult = result;
-
+	m_con.reset(new DesktopConnector(m_password.c_str(), "UTF-8", result));
 	DoConnect();
 }
 
 void BarryEnvironment::Reconnect()
 {
-	Disconnect();
-
-	// FIXME - temporary fix for odd reconnect message... without this
-	// probe, the reconnect will often fail on newer Blackberries
-	// due to an unexpected close socket message.  It is unclear
-	// if this is really a message from the device, but until then,
-	// we add this probe.
-	{
-		Barry::Probe probe;
-		int i = probe.FindActive(m_ProbeResult.m_pin);
-		if( i != -1 )
-			m_ProbeResult = probe.Get(i);
-	}
-
-	DoConnect();
+	m_con->Reconnect(2);
 }
 
 void BarryEnvironment::Disconnect()
 {
-	delete m_pDesktop;
-	m_pDesktop = 0;
-
-	delete m_pCon;
-	m_pCon = 0;
+	m_con->Disconnect();
 }
 
 void BarryEnvironment::ClearDirtyFlags(Barry::RecordStateTable &table,
@@ -247,14 +233,14 @@ void BarryEnvironment::ClearDirtyFlags(Barry::RecordStateTable &table,
 {
 	Trace trace("ClearDirtyFlags");
 
-	unsigned int dbId = m_pDesktop->GetDBID(dbname);
+	unsigned int dbId = m_con->GetDesktop().GetDBID(dbname);
 
 	Barry::RecordStateTable::StateMapType::const_iterator i = table.StateMap.begin();
 	for( ; i != table.StateMap.end(); ++i ) {
 		if( i->second.Dirty ) {
-			trace.logf("Clearing dirty flag for db %u, index %u",
+			trace.logf(_("Clearing dirty flag for db %u, index %u"),
 				dbId, i->first);
-			m_pDesktop->ClearDirty(dbId, i->first);
+			m_con->GetDesktop().ClearDirty(dbId, i->first);
 		}
 	}
 }
@@ -309,7 +295,7 @@ void BarryEnvironment::ParseConfig(const char *data, int size)
 	//           - sync contacts
 
 	std::istringstream iss(m_ConfigData);
-	std::string line, key;
+	std::string line;
 	while( std::getline(iss, line) ) {
 
 		if( line[0] == '#' )
@@ -318,6 +304,7 @@ void BarryEnvironment::ParseConfig(const char *data, int size)
 		std::istringstream ils(line);
 		int cal = 0, con = 0;
 
+		std::string key;
 		ils >> key;
 
 		if( key == "DebugMode" ) {
@@ -332,17 +319,17 @@ void BarryEnvironment::ParseConfig(const char *data, int size)
 
 			if( cal ) {
 				m_CalendarSync.m_Sync = true;
-				trace.log("calendar syncing enabled");
+				trace.log(_("calendar syncing enabled"));
 			}
 
 			if( con ) {
 				m_ContactsSync.m_Sync = true;
-				trace.log("contacts syncing enabled");
+				trace.log(_("contacts syncing enabled"));
 			}
 		}
 		else if ( key == "Password" ) {
 			ils >> m_password;
-			trace.log("using password from config file");
+			trace.log(_("using password from config file"));
 		}
 	}
 }
