@@ -4,7 +4,7 @@
 //
 
 /*
-    Copyright (C) 2006-2009, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2006-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include <opensync/opensync.h>
 #include <barry/barry.h>
 #include <string>
+#include <memory>
 #include "idmap.h"
 
 
@@ -75,6 +76,9 @@ public:
 
 struct BarryEnvironment
 {
+private:
+	std::string m_password;
+
 public:
 	OSyncMember *member;
 
@@ -82,13 +86,9 @@ public:
 	std::string m_ConfigData;
 	uint32_t m_pin;
 	bool m_DebugMode;
-	std::string m_password;
 
 	// device communication
-	Barry::IConverter m_IConverter;
-	Barry::ProbeResult m_ProbeResult;
-	Barry::Controller *m_pCon;
-	Barry::Mode::Desktop *m_pDesktop;
+	std::auto_ptr<Barry::DesktopConnector> m_con;
 
 	// sync data
 	DatabaseSyncState m_CalendarSync, m_ContactsSync;
@@ -100,6 +100,9 @@ public:
 	BarryEnvironment(OSyncMember *pm);
 	~BarryEnvironment();
 
+	Barry::Mode::Desktop* GetDesktop() { return &m_con->GetDesktop(); }
+	void SetPassword(const std::string &password);
+
 	void Connect(const Barry::ProbeResult &result);
 	void Reconnect();
 	void Disconnect();
