@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2007-2009, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2007-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,8 +22,10 @@
 #ifndef __BARRY_DATAQUEUE_H__
 #define __BARRY_DATAQUEUE_H__
 
-#include <queue>
+#include "dll.h"
+#include <list>
 #include <pthread.h>
+#include <iosfwd>
 
 namespace Barry {
 
@@ -37,9 +39,10 @@ class Data;
 ///
 /// It uses similar member names as std::queue<>, for consistency.
 ///
-class DataQueue
+class BXEXPORT DataQueue
 {
-	typedef std::queue<Data*>			queue_type;
+	// always use the raw_push() and raw_pop() functions
+	typedef std::list<Data*>			queue_type;
 
 	pthread_mutex_t m_waitMutex;
 	pthread_cond_t m_waitCond;
@@ -48,6 +51,10 @@ class DataQueue
 
 	queue_type m_queue;
 
+protected:
+	void raw_push(Data *data);
+	Data* raw_pop();
+
 public:
 	DataQueue();
 	~DataQueue();		// frees all data in the queue
@@ -78,8 +85,16 @@ public:
 
 	bool empty() const;	// return true if empty
 	size_t size() const;
+
+	void DumpAll(std::ostream &os) const;
 };
 
+inline std::ostream& operator<< (std::ostream &os, const DataQueue &dq)
+{
+	dq.DumpAll(os);
+	return os;
+}
+
 } // namespace Barry
 
 #endif
