@@ -6,7 +6,7 @@
 ///
 
 /*
-    Copyright (C) 2005-2009, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2005-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -53,6 +53,21 @@
 #define BXEXPORT __attribute__ ((visibility("default")))
 #define BXLOCAL __attribute__ ((visibility("hidden")))
 
+#elif defined(WIN32)
+
+#ifdef __BARRY_LIBRARY_BUILD__
+#define BXEXPORT __declspec( dllexport ) 
+#define BXLOCAL
+#else
+#define BXEXPORT __declspec( dllimport ) 
+#define BXLOCAL
+#endif
+
+// Disable "needs to have dll interface warning" which
+// comes from exporting classes which make use of non-exported 
+// templated classes.
+#pragma warning(disable: 4251)
+
 #else
 
 #define BXEXPORT
@@ -60,5 +75,29 @@
 
 #endif
 
+
+//
+// Add this to the end of variable argument function declarations.
+// For example:
+//
+//   void log(const char *msg, ...) BARRY_GCC_FORMAT_CHECK(1, 2);
+//
+// This tells GCC that the first argument is the format string, and
+// the second is the first variable argument to check.
+//
+// If you use this inside a class, you need to allow for the invisible
+// 'this' pointer:
+//
+//   class Trace {
+//     public:
+//       void logf(const char *msg, ...) BARRY_GCC_FORMAT_CHECK(2, 3);
+//   };
+//
+#if __GNUC__
+#define BARRY_GCC_FORMAT_CHECK(a,b) __attribute__ ((format(printf, a, b)))
+#else
+#define BARRY_GCC_FORMAT_CHECK(a,b)
+#endif
+
 #endif
 
