@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2005-2012, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2005-2013, Net Direct Inc. (http://www.netdirect.ca/)
     Copyright (C) 2008-2009, Nicolas VIVIEN
 
         Some parts are inspired from m_desktop.h
@@ -87,6 +87,7 @@ public:
 	JLDirectory SubDir;
 
 public:
+	JLDirectoryEntry();
 	explicit JLDirectoryEntry(int level);
 
 	void Parse(uint16_t id, const Data &entry_packet);
@@ -182,7 +183,7 @@ public:
 
 public:
 	uint32_t	HardwareId;
-	struct Pin	Pin;
+	class Pin	Pin;
 	VersionQuad	OsVersion;
 	VersionQuad	VmVersion;
 	uint32_t	RadioId;
