@@ -6,7 +6,7 @@
 ///
 
 /*
-    Copyright (C) 2005-2012, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2005-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
     root directory of this project for more details.
 */
 
+#include "i18n.h"
 #include "packet.h"
 #include "m_desktop.h"
 #include "protocol.h"
@@ -461,7 +462,7 @@ unsigned int DBPacket::ReturnCode() const
 		return rpack->u.db.u.return_code;
 	}
 	else {
-		throw Error("Attempting to extract a return code from the wrong response packet type");
+		throw Error(_("Attempting to extract a return code from the wrong response packet type"));
 	}
 }
 
@@ -663,7 +664,7 @@ int JLPacket::GetScreenshot()
 
 int JLPacket::Erase(uint16_t cmd, uint16_t id)
 {
-	SimpleCmd(cmd, 0, 2);
+	SimpleCmd((uint8_t)cmd, 0, 2);
 	return BigEndianData(id);
 }
 
