@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2005-2009, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2005-2013, Net Direct Inc. (http://www.netdirect.ca/)
     Copyright (C) 2007, Brian Edginton
 
     This program is free software; you can redistribute it and/or modify
@@ -20,6 +20,7 @@
     root directory of this project for more details.
 */
 
+#include "i18n.h"
 #include "r_folder.h"
 #include "record-internal.h"
 #include "protostructs.h"
@@ -27,8 +28,10 @@
 #include "time.h"
 #include "debug.h"
 #include "iconv.h"
-#include <ostream>
+#include <iostream>
+#include <sstream>
 #include <iomanip>
+#include "ios_state.h"
 
 using namespace std;
 using namespace Barry::Protocol;
@@ -78,8 +81,8 @@ uint8_t Folder::TypeRec2Proto(FolderType t)
 #define ROOT_SEPARATOR	0x3a
 
 static FieldLink<Folder> FolderFieldLinks[] = {
-    { FFC_NAME, "FolderName",  0, 0, &Folder::Name, 0, 0, 0, 0, true },
-    { FFC_END,  "End of List", 0, 0, 0, 0, 0, 0, 0, false },
+    { FFC_NAME, N_("FolderName"),  0, 0, &Folder::Name, 0, 0, 0, 0, true },
+    { FFC_END,  N_("End of List"), 0, 0, 0, 0, 0, 0, 0, false },
 };
 
 Folder::Folder()
@@ -120,8 +123,8 @@ const unsigned char* Folder::ParseField(const unsigned char *begin,
 				return begin;   // done!
 			}
 			else if( b->timeMember && btohs(field->size) == 4 ) {
-				time_t &t = this->*(b->timeMember);
-				t = min2time(field->u.min1900);
+				TimeT &t = this->*(b->timeMember);
+				t.Time= min2time(field->u.min1900);
 				return begin;
 			}
 		}
@@ -162,29 +165,106 @@ void Folder::ParseFields(const Data &data, size_t &offset, const IConverter *ic)
 	offset += finish - (data.GetData() + offset);
 }
 
+void Folder::Validate() const
+{
+}
+
+void Folder::BuildHeader(Data &data, size_t &offset) const
+{
+	// not yet implemented
+}
+
+void Folder::BuildFields(Data &data, size_t &offset, const IConverter *ic) const
+{
+	// not yet implemented
+}
+
 void Folder::Clear()
 {
+	RecType = GetDefaultRecType();
+	RecordId = 0;
+
 	Name.clear();
-	Unknowns.clear();
+	Number = 0;
+	Level = 0;
+
 	Type = FolderSubtree;
+
+	Unknowns.clear();
+}
+
+const FieldHandle<Folder>::ListT& Folder::GetFieldHandles()
+{
+	static FieldHandle<Folder>::ListT fhv;
+
+	if( fhv.size() )
+		return fhv;
+
+#undef CONTAINER_OBJECT_NAME
+#define CONTAINER_OBJECT_NAME fhv
+
+#undef RECORD_CLASS_NAME
+#define RECORD_CLASS_NAME Folder
+
+	FHP(RecType, _("Record Type Code"));
+	FHP(RecordId, _("Unique Record ID"));
+
+	FHD(Name, _("Folder Name"), FFC_NAME, true);
+	FHD(Number, _("Order Number"), FFC_NUMBER, false);
+	FHD(Level, _("Folder Level"), FFC_LEVEL, false);
+
+	FHE(ft, FolderType, Type, _("Folder Type"));
+	FHE_CONST(ft, FolderSubtree, _("Subtree"));
+	FHE_CONST(ft, FolderDeleted, _("Deleted"));
+	FHE_CONST(ft, FolderInbox, _("Inbox"));
+	FHE_CONST(ft, FolderOutbox, _("Outbox"));
+	FHE_CONST(ft, FolderSent, _("Sent"));
+	FHE_CONST(ft, FolderOther, _("Other"));
+	FHE_CONST(ft, FolderDraft, _("Draft"));
+
+// Not yet implemented
+//	FHE(fst, FolderStatusType, ..., _("Folder Status"));
+//	FHE_CONST(fst, FolderOrphan, _("Orphan"));
+//	FHE_CONST(fst, FolderUnfiled, _("Unfiled"));
+//	FHE_CONST(fst, FolderFiled, _("Filed"));
+
+	FHP(Unknowns, _("Unknown Fields"));
+
+	return fhv;
+}
+
+std::string Folder::GetDescription() const
+{
+	ostringstream oss;
+	oss << Name << " (" << Level << ")";
+	return oss.str();
 }
 
 void Folder::Dump(std::ostream &os) const
 {
-	static const char *FolderTypeString[] = { "Subtree", "Deleted", "Inbox", "Outbox", "Sent", "Other"};
+	ios_format_state state(os);
+
+	static const char *FolderTypeString[] = {
+		N_("Subtree"),
+		N_("Deleted"),
+		N_("Inbox"),
+		N_("Outbox"),
+		N_("Sent"),
+		N_("Other")
+	};
 //	static const char *FolderStatusString[] = { "Orphan", "Unfiled", "Filed" };
 
-	os << "Folder Records\n\n";
-	os << "Folder Name: " << Name << "\n";
-	os << "Folder Type: ";
+	os << _("Folder Records\n\n");
+	os << _("Folder Name: ") << Name << "\n";
+	os << _("Folder Type: ");
 	if( Type < FolderDraft )
-		os << FolderTypeString[Type] << "\n";
+		os << gettext( FolderTypeString[Type] ) << "\n";
 	else if( Type == FolderDraft )
-		os << "Draft\n";
+		os << _("Draft\n");
 	else
-		os << "Unknown (" << std::hex << Type << ")\n";
-	os << "Folder Number: " << std::dec << Number << "\n";
-	os << "Folder Level: " << std::dec << Level << "\n";
+		os << _("Unknown") << " (" << std::hex << Type << ")\n";
+	os << _("Folder Number: ") << std::dec << Number << "\n";
+	os << _("Folder Level: ") << std::dec << Level << "\n";
 	os << "\n";
 	os << Unknowns;
 	os << "\n\n";
