@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2005-2009, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2005-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,9 +38,26 @@ namespace Barry {
 class BXEXPORT Message : public MessageBase
 {
 public:
+	Message()
+	{
+		// must call this again, since base class can't call ours
+		Clear();
+	}
+
+	void Clear()
+	{
+		MessageBase::Clear();
+
+		RecType = GetDefaultRecType();
+		RecordId = 0;
+	}
+
 	// database name
 	static const char * GetDBName() { return "Messages"; }
 	static uint8_t GetDefaultRecType() { return 0; }
+
+	// Generic Field Handle support
+	static const FieldHandle<Message>::ListT& GetFieldHandles();
 };
 
 BXEXPORT inline std::ostream& operator<<(std::ostream &os, const Message &msg) {
