@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2008-2009, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2008-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,25 +19,49 @@
     root directory of this project for more details.
 */
 
+#include "i18n.h"
 #include "router.h"
 #include "scoped_lock.h"
 #include "data.h"
 #include "protostructs.h"
+#include "protocol.h"
 #include "usbwrap.h"
 #include "endian.h"
 #include "debug.h"
 #include <unistd.h>
+#include <iostream>
+#include <iomanip>
+
+using namespace std;
 
 namespace Barry {
 
+///////////////////////////////////////////////////////////////////////////////
+// SocketDataHandler default methods
+
+void SocketRoutingQueue::SocketDataHandler::Error(Barry::Error &error)
+{
+	// Just log the error
+	eout("SocketDataHandler: Error: " << error.what());
+	(void) error;
+}
+
+SocketRoutingQueue::SocketDataHandler::~SocketDataHandler()
+{
+	// Nothing to destroy
+}
+
 ///////////////////////////////////////////////////////////////////////////////
 // SocketRoutingQueue constructors
 
-SocketRoutingQueue::SocketRoutingQueue(int prealloc_buffer_count)
+SocketRoutingQueue::SocketRoutingQueue(int prealloc_buffer_count,
+					int default_read_timeout)
 	: m_dev(0)
 	, m_writeEp(0)
 	, m_readEp(0)
 	, m_interest(false)
+	, m_seen_usb_error(false)
+	, m_timeout(default_read_timeout)
 	, m_continue_reading(false)
 {
 	pthread_mutex_init(&m_mutex, NULL);
@@ -55,6 +79,16 @@ SocketRoutingQueue::~SocketRoutingQueue()
 		m_continue_reading = false;
 		pthread_join(m_usb_read_thread, NULL);
 	}
+
+	// dump all unused packets to debug output
+	SocketQueueMap::const_iterator b = m_socketQueues.begin();
+	for( ; b != m_socketQueues.end(); ++b ) {
+		DumpSocketQueue(b->first, b->second->m_queue);
+	}
+	if( m_default.size() ) {
+		ddout("(Default queue is socket 0)");
+		DumpSocketQueue(0, m_default);
+	}
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -72,6 +106,79 @@ void SocketRoutingQueue::ReturnBuffer(Data *buf)
 	m_free.push(buf);
 }
 
+//
+// QueuePacket
+//
+/// Helper function to add a buffer to a socket queue.
+/// Returns false if no queue is available for that socket.
+//// Also empties the DataHandle on success.
+///
+bool SocketRoutingQueue::QueuePacket(SocketId socket, DataHandle &buf)
+{
+	if( m_interest ) {
+		// lock so we can access the m_socketQueues map safely
+		scoped_lock lock(m_mutex);
+
+		// search for registration of socket
+		SocketQueueMap::iterator qi = m_socketQueues.find(socket);
+		if( qi != m_socketQueues.end() ) {
+			qi->second->m_queue.push(buf.release());
+			return true;
+		}
+	}
+
+	return false;
+}
+
+bool SocketRoutingQueue::QueuePacket(DataQueue &queue, DataHandle &buf)
+{
+	// don't need to lock here, since queue handles its own locking
+	queue.push(buf.release());
+	return true;
+}
+
+//
+// RouteOrQueuePacket
+//
+/// Same as QueuePacket, except sends the data to the callback if
+/// a callback is available.
+///
+/// This function duplicates code from QueuePacket(), in order to
+/// optimize the mutex locking.
+///
+bool SocketRoutingQueue::RouteOrQueuePacket(SocketId socket, DataHandle &buf)
+{
+	// search for registration of socket
+	if( m_interest ) {
+		// lock so we can access the m_socketQueues map safely
+		scoped_lock lock(m_mutex);
+
+		SocketQueueMap::iterator qi = m_socketQueues.find(socket);
+		if( qi != m_socketQueues.end() ) {
+			SocketDataHandlerPtr &sdh = qi->second->m_handler;
+
+			// is there a handler?
+			if( sdh ) {
+				// unlock & let the handler process it
+				lock.unlock();
+				sdh->DataReceived(*buf.get());
+
+				// no exceptions thrown, clear the
+				// DataHandle, sending packet back to its
+				// free list
+				buf.reset();
+				return true;
+			}
+			else {
+				qi->second->m_queue.push(buf.release());
+				return true;
+			}
+		}
+	}
+
+	return false;
+}
+
 //
 // SimpleReadThread()
 //
@@ -82,15 +189,34 @@ void *SocketRoutingQueue::SimpleReadThread(void *userptr)
 	SocketRoutingQueue *q = (SocketRoutingQueue *)userptr;
 
 	// read from USB and write to stdout until finished
-	std::string msg;
+	q->m_seen_usb_error = false;
 	while( q->m_continue_reading ) {
-		if( !q->DoRead(msg, 1000) ) {	// timeout in milliseconds
-			eout("Error in SimpleReadThread: " << msg);
+		try {
+			q->DoRead(1000);	// timeout in milliseconds
+		}
+		catch (std::runtime_error const &e) {
+			eout(_("SimpleReadThread received uncaught exception: ") <<  typeid(e).name() << _(" what: ") << e.what());
+		}
+		catch (...) {
+			eout(_("SimpleReadThread recevied uncaught exception of unknown type"));
 		}
 	}
 	return 0;
 }
 
+void SocketRoutingQueue::DumpSocketQueue(SocketId socket, const DataQueue &dq)
+{
+	// dump a record of any unused packets in the queue, for debugging
+	if( dq.size() ) {
+		ddout(_("SocketRoutingQueue Leftovers: ")
+			<< dec << dq.size()
+			<< _(" packet(s) for socket: ") << "0x"
+			<< hex << (unsigned int) socket
+			<< "\n"
+			<< dq);
+	}
+}
+
 
 ///////////////////////////////////////////////////////////////////////////////
 // public API
@@ -98,10 +224,12 @@ void *SocketRoutingQueue::SimpleReadThread(void *userptr)
 // These functions connect the router to an external Usb::Device
 // object.  Normally this is handled automatically by the
 // Controller class, but are public here in case they are needed.
-void SocketRoutingQueue::SetUsbDevice(Usb::Device *dev, int writeEp, int readEp)
+void SocketRoutingQueue::SetUsbDevice(Usb::Device *dev, int writeEp, int readEp,
+					SocketDataHandlerPtr callback)
 {
 	scoped_lock lock(m_mutex);
 	m_dev = dev;
+	m_usb_error_dev_callback = callback;
 	m_writeEp = writeEp;
 	m_readEp = readEp;
 }
@@ -110,6 +238,7 @@ void SocketRoutingQueue::ClearUsbDevice()
 {
 	scoped_lock lock(m_mutex);
 	m_dev = 0;
+	m_usb_error_dev_callback.reset();
 	lock.unlock();
 
 	// wait for the DoRead cycle to finish, so the external
@@ -121,7 +250,7 @@ void SocketRoutingQueue::ClearUsbDevice()
 bool SocketRoutingQueue::UsbDeviceReady()
 {
 	scoped_lock lock(m_mutex);
-	return m_dev != 0;
+	return m_dev != 0 && !m_seen_usb_error;
 }
 
 //
@@ -170,8 +299,18 @@ bool SocketRoutingQueue::DefaultRead(Data &receive, int timeout)
 ///
 DataHandle SocketRoutingQueue::DefaultRead(int timeout)
 {
+	if( m_seen_usb_error && timeout == -1 ) {
+		// If an error has been seen and not cleared then no
+		// more data will be read into the queue by
+		// DoRead(). Forcing the timeout to zero allows any
+		// data already in the queue to be read, but prevents
+		// waiting for data which will never arrive.
+		timeout = 0;
+	}
+
 	// m_default handles its own locking
-	Data *buf = m_default.wait_pop(timeout);
+	// Be careful with the queue timeout, since its -1 means "forever"
+	Data *buf = m_default.wait_pop(timeout == -1 ? m_timeout : timeout);
 	return DataHandle(*this, buf);
 }
 
@@ -194,17 +333,16 @@ DataHandle SocketRoutingQueue::DefaultRead(int timeout)
 /// Throws std::logic_error if already registered.
 ///
 void SocketRoutingQueue::RegisterInterest(SocketId socket,
-					  SocketDataHandler handler,
-					  void *context)
+					  SocketDataHandlerPtr handler)
 {
 	// modifying our own std::map, need a lock
 	scoped_lock lock(m_mutex);
 
 	SocketQueueMap::iterator qi = m_socketQueues.find(socket);
 	if( qi != m_socketQueues.end() )
-		throw std::logic_error("RegisterInterest requesting a previously registered socket.");
+		throw std::logic_error(_("RegisterInterest requesting a previously registered socket."));
 
-	m_socketQueues[socket] = QueueEntryPtr( new QueueEntry(handler, context) );
+	m_socketQueues[socket] = QueueEntryPtr( new QueueEntry(handler) );
 	m_interest = true;
 }
 
@@ -224,6 +362,9 @@ void SocketRoutingQueue::UnregisterInterest(SocketId socket)
 	if( qi == m_socketQueues.end() )
 		return;	// nothing registered, done
 
+	// dump a record of any unused packets in the queue, for debugging
+	DumpSocketQueue(qi->first, qi->second->m_queue);
+
 	// salvage all our data buffers
 	m_free.append_from( qi->second->m_queue );
 
@@ -278,7 +419,7 @@ DataHandle SocketRoutingQueue::SocketRead(SocketId socket, int timeout)
 		scoped_lock lock(m_mutex);
 		SocketQueueMap::iterator qi = m_socketQueues.find(socket);
 		if( qi == m_socketQueues.end() )
-			throw std::logic_error("SocketRead requested data from unregistered socket.");
+			throw std::logic_error(_("SocketRead requested data from unregistered socket."));
 
 		// got our queue, save the whole QueueEntryPtr (shared_ptr),
 		// and unlock, since we will be waiting on the DataQueue,
@@ -296,7 +437,8 @@ DataHandle SocketRoutingQueue::SocketRead(SocketId socket, int timeout)
 	}
 
 	// get data from DataQueue
-	Data *buf = dq->wait_pop(timeout);
+	// Be careful with the queue timeout, since its -1 means "forever"
+	Data *buf = dq->wait_pop(timeout == -1 ? m_timeout : timeout);
 
 	// specifically delete our copy of shared pointer, in a locked
 	// environment
@@ -329,11 +471,9 @@ bool SocketRoutingQueue::IsAvailable(SocketId socket) const
 /// device to work with.
 ///
 /// Timeout is in milliseconds.
-///
-/// Returns false in the case of USB errors and puts the error message
-/// in msg.
-///
-bool SocketRoutingQueue::DoRead(std::string &msg, int timeout)
+//  This timeout is for the USB subsystem, so no special handling
+//  for it is needed... just use usbwrap's default timeout.
+void SocketRoutingQueue::DoRead(int timeout)
 {
 	class ReadWaitSignal
 	{
@@ -358,12 +498,12 @@ bool SocketRoutingQueue::DoRead(std::string &msg, int timeout)
 	{
 		scoped_lock lock(m_mutex);
 
-		if( !m_dev ) {
+		if( !m_dev || m_seen_usb_error ) {
 			lock.unlock();	// unlock early, since we're sleeping
 			// sleep only a short time, since things could be
 			// in the process of setup or teardown
 			usleep(125000);
-			return true;
+			return;
 		}
 
 		dev = m_dev;
@@ -384,63 +524,82 @@ bool SocketRoutingQueue::DoRead(std::string &msg, int timeout)
 		Data &data = *buf.get();
 
 		if( !dev->BulkRead(readEp, data, timeout) )
-			return true;	// no data, done!
+			return;	// no data, done!
 
 		MAKE_PACKET(pack, data);
 
 		// make sure the size is right
-		if( data.GetSize() < sizeof(pack->socket) )
-			return true;	// bad size, just skip
+		if( data.GetSize() < SB_PACKET_SOCKET_SIZE )
+			return;	// bad size, just skip
 
 		// extract the socket from the packet
 		uint16_t socket = btohs(pack->socket);
 
-		// we have data, now lock up again to place it
-		// in the right queue
-		scoped_lock lock(m_mutex);
+		// if this is a sequence packet, handle it specially
+		if( Protocol::IsSequencePacket(data) ) {
+			// sequence.socket is a single byte
+			socket = pack->u.sequence.socket;
 
-		// search for registration of socket
-		if( m_interest ) {
-			SocketQueueMap::iterator qi = m_socketQueues.find(socket);
-			if( qi != m_socketQueues.end() ) {
-				SocketDataHandler sdh = qi->second->m_handler;
-				void *ctx = qi->second->m_context;
-
-				// is there a handler?
-				if( sdh ) {
-					// unlock & let the handler process it
-					lock.unlock();
-					(*sdh)(ctx, buf.get());
-					return true;
-				}
-				else {
-					qi->second->m_queue.push(buf.release());
-					return true;
-				}
+			//////////////////////////////////////////////
+			// ALWAYS queue sequence packets, so that
+			// the socket code can handle SyncSend()
+			if( !QueuePacket(socket, buf) ) {
+				// if no queue available for this
+				// socket, send it to the default
+				// queue
+				QueuePacket(m_default, buf);
 			}
 
-			// fall through
+			// done with sequence packet
+			return;
 		}
 
-		// safe to unlock now, we are done with the map
-		lock.unlock();
+		// we have data, now route or queue it
+		if( RouteOrQueuePacket(socket, buf) )
+			return; // done
 
 		// if we get here, send to default queue
-		m_default.push(buf.release());
-		return true;
-
+		QueuePacket(m_default, buf);
 	}
 	catch( Usb::Timeout & ) {
 		// this is expected... just ignore
 	}
 	catch( Usb::Error &ue ) {
-		// this is unexpected, but we're in a thread here...
-		// return false and the caller decide how to handle it
-		msg = ue.what();
-		return false;
-	}
+		// set the flag first, in case any of the handlers
+		// are able to recover from this error
+		m_seen_usb_error = true;
 
-	return true;
+		// this is unexpected, but we're in a thread here...
+		// Need to iterate through all the registered handlers
+		// calling their error callback.
+		// Can't be locked when calling the callback, so need
+		// to make a list of them first.
+		scoped_lock lock(m_mutex);
+		std::vector<SocketDataHandlerPtr> handlers;
+		SocketQueueMap::iterator qi = m_socketQueues.begin();
+		while( qi != m_socketQueues.end() ) {
+			SocketDataHandlerPtr &sdh = qi->second->m_handler;
+			// is there a handler?
+			if( sdh ) {
+				handlers.push_back(sdh);
+			}
+			++qi;
+		}
+
+		SocketDataHandlerPtr usb_error_handler = m_usb_error_dev_callback;
+
+		lock.unlock();
+		std::vector<SocketDataHandlerPtr>::iterator hi = handlers.begin();
+		while( hi != handlers.end() ) {
+			(*hi)->Error(ue);
+			++hi;
+		}
+
+		// and finally, call the specific error callback if available
+		if( usb_error_handler.get() ) {
+			usb_error_handler->Error(ue);
+		}
+	}
 }
 
 void SocketRoutingQueue::SpinoffSimpleReadThread()
@@ -454,7 +613,7 @@ void SocketRoutingQueue::SpinoffSimpleReadThread()
 	int ret = pthread_create(&m_usb_read_thread, NULL, &SimpleReadThread, this);
 	if( ret ) {
 		m_continue_reading = false;
-		throw Barry::ErrnoError("SocketRoutingQueue: Error creating USB read thread.", ret);
+		throw Barry::ErrnoError(_("SocketRoutingQueue: Error creating USB read thread."), ret);
 	}
 }
 
