@@ -20,6 +20,7 @@
  *
  */
 
+#include "i18n.h"
 #include "vformat.h"
 #include "clog.h"
 
@@ -106,7 +107,7 @@ time_t b_vformat_time_to_unix(const char *inptime)
 	return utime;
 }
 
-static char *_fold_lines (char *buf)
+static char *_unfold_lines (char *buf)
 {
 	GString *str = g_string_new ("");
 	GString *line = g_string_new ("");
@@ -145,7 +146,7 @@ static char *_fold_lines (char *buf)
 				if (*next2 == '\n' || *next2 == '\r' || *next2 == ' ' || *next2 == '\t') {
 					p = g_utf8_next_char (next2);
 				}
-				else if(quotedprintable) {
+				else if(quotedprintable && (*p == '=')) {
 					p = g_utf8_next_char (next);
 				}
 				else {
@@ -409,7 +410,7 @@ static void _read_attribute_value (b_VFormatAttribute *attr, char **p, int forma
 				  /* \t is (incorrectly) used by kOrganizer, so handle it here */
 				case 't': str = g_string_append_c (str, '\t'); break;
 				default:
-					BarryLogf(TRACE_INTERNAL, "invalid escape, passing it through. escaped char was %u", (unsigned int)*lp);
+					BarryLogf(TRACE_INTERNAL, _("invalid escape, passing it through. escaped char was %u"), (unsigned int)*lp);
 					str = g_string_append_c (str, '\\');
 					str = g_string_append_unichar (str, g_utf8_get_char(lp));
 					break;
@@ -578,7 +579,7 @@ static void _read_attribute_params(b_VFormatAttribute *attr, char **p, int *form
 				break;
 		}
 		else {
-			BarryLogf(TRACE_INTERNAL, "invalid character found in parameter spec: \"%i\" String so far: %s", lp[0], str->str);
+			BarryLogf(TRACE_INTERNAL, _("invalid character found in parameter spec: \"%i\" String so far: %s"), lp[0], str->str);
 			g_string_assign (str, "");
 			_skip_until (&lp, ":;");
 		}
@@ -627,7 +628,7 @@ static b_VFormatAttribute *_read_attribute (char **p)
 		}
 		else if (*lp == '.') {
 			if (attr_group) {
-				BarryLogf(TRACE_INTERNAL, "extra `.' in attribute specification.  ignoring extra group `%s'", str->str);
+				BarryLogf(TRACE_INTERNAL, _("extra `.' in attribute specification.  ignoring extra group `%s'"), str->str);
 				g_string_free (str, TRUE);
 				str = g_string_new ("");
 			}
@@ -640,7 +641,7 @@ static b_VFormatAttribute *_read_attribute (char **p)
 			str = g_string_append_unichar (str, g_utf8_get_char (lp));
 		}
 		else {
-			BarryLogf(TRACE_INTERNAL, "invalid character found in attribute group/name: \"%i\" String so far: %s", lp[0], str->str);
+			BarryLogf(TRACE_INTERNAL, _("invalid character found in attribute group/name: \"%i\" String so far: %s"), lp[0], str->str);
 			g_string_free (str, TRUE);
 			*p = lp;
 			_skip_to_next_line(p);
@@ -728,11 +729,11 @@ static void _parse(b_VFormat *evc, const char *str)
 	/* first validate the string is valid utf8 */
 	if (!g_utf8_validate (buf, -1, (const char **)&end)) {
 		/* if the string isn't valid, we parse as much as we can from it */
-		BarryLogf(TRACE_INTERNAL, "invalid utf8 passed to b_VFormat.  Limping along.");
+		BarryLogf(TRACE_INTERNAL, _("invalid utf8 passed to b_VFormat.  Limping along."));
 		*end = '\0';
 	}
 
-	buf = _fold_lines (buf);
+	buf = _unfold_lines (buf);
 
 	p = buf;
 
@@ -741,7 +742,7 @@ static void _parse(b_VFormat *evc, const char *str)
 		attr = _read_attribute (&p);
 
 	if (!attr || attr->group || g_ascii_strcasecmp (attr->name, "begin")) {
-		BarryLogf(TRACE_INTERNAL, "vformat began without a BEGIN\n");
+		BarryLogf(TRACE_INTERNAL, _("vformat began without a BEGIN\n"));
 	}
 	if (attr && !g_ascii_strcasecmp (attr->name, "begin"))
 		b_vformat_attribute_free (attr);
@@ -778,7 +779,7 @@ static void _parse(b_VFormat *evc, const char *str)
 	}
 
 	if (!attr || attr->group || g_ascii_strcasecmp (attr->name, "end")) {
-		BarryLogf(TRACE_INTERNAL, "vformat ended without END");
+		BarryLogf(TRACE_INTERNAL, _("vformat ended without END"));
 	}
 
 	g_free (buf);
@@ -819,11 +820,11 @@ char *b_vformat_escape_string (const char *s, b_VFormatType type)
 			 * See comments above for a better explanation
 			**/
 			if (*p != '\0' && type == VFORMAT_CARD_21) {
-				BarryLogf(TRACE_INTERNAL, "[%s]We won't escape backslashes", __func__);
+				BarryLogf(TRACE_INTERNAL, _("[%s]We won't escape backslashes"), __func__);
 				str = g_string_append_c(str, *p);
 			}
 			else {
-				BarryLogf(TRACE_INTERNAL, "[%s] escape backslashes!!", __func__);
+				BarryLogf(TRACE_INTERNAL, _("[%s] escape backslashes!!"), __func__);
 				str = g_string_append (str, "\\\\");
 			}
 			break;
@@ -864,7 +865,7 @@ b_vformat_unescape_string (const char *s)
 			  /* \t is (incorrectly) used by kOrganizer, so handle it here */
 			case 't': str = g_string_append_c (str, '\t'); break;
 			default:
-				BarryLogf(TRACE_INTERNAL, "invalid escape, passing it through. escaped char was %u", (unsigned int)*p);
+				BarryLogf(TRACE_INTERNAL, _("invalid escape, passing it through. escaped char was %u"), (unsigned int)*p);
 				str = g_string_append_c (str, '\\');
 				str = g_string_append_unichar (str, g_utf8_get_char(p));
 				break;
@@ -1052,7 +1053,7 @@ char *b_vformat_to_string (b_VFormat *evc, b_VFormatType type)
 					 * eliminated.
 					**/
 					if (!g_ascii_strcasecmp (param->name, "ENCODING") && !g_ascii_strcasecmp ((char *) v->data, "QUOTED-PRINTABLE")) {
-						BarryLogf(TRACE_ERROR, "%s false encoding QUOTED-PRINTABLE is not allowed", __func__);
+						BarryLogf(TRACE_ERROR, _("%s false encoding QUOTED-PRINTABLE is not allowed"), __func__);
 						format_encoding = VF_ENCODING_QP;
 					}
 					attr_str = g_string_append (attr_str, v->data);
@@ -1396,7 +1397,7 @@ b_vformat_attribute_add_value_decoded (b_VFormatAttribute *attr, const char *val
 
 	switch (attr->encoding) {
 		case VF_ENCODING_RAW:
-			BarryLogf(TRACE_INTERNAL, "can't add_value_decoded with an attribute using RAW encoding.  you must set the ENCODING parameter first");
+			BarryLogf(TRACE_INTERNAL, _("can't add_value_decoded with an attribute using RAW encoding.  you must set the ENCODING parameter first"));
 			break;
 		case VF_ENCODING_BASE64: {
 			char *b64_data = base64_encode_simple (value, len);
@@ -1536,7 +1537,7 @@ b_vformat_attribute_add_param (b_VFormatAttribute *attr,
 
 	if (!g_ascii_strcasecmp (param->name, "ENCODING")) {
 		if (attr->encoding_set) {
-			BarryLogf(TRACE_INTERNAL, "ENCODING specified twice");
+			BarryLogf(TRACE_INTERNAL, _("ENCODING specified twice"));
 			return;
 		}
 
@@ -1548,13 +1549,13 @@ b_vformat_attribute_add_param (b_VFormatAttribute *attr,
 			else if (!g_ascii_strcasecmp ((char *)param->values->data, "8BIT"))
 				attr->encoding = VF_ENCODING_8BIT;
 			else {
-				BarryLogf(TRACE_INTERNAL, "Unknown value `%s' for ENCODING parameter.  values will be treated as raw", (char*)param->values->data);
+				BarryLogf(TRACE_INTERNAL, _("Unknown value `%s' for ENCODING parameter.  values will be treated as raw"), (char*)param->values->data);
 			}
 
 			attr->encoding_set = TRUE;
 		}
 		else {
-			BarryLogf(TRACE_INTERNAL, "ENCODING parameter added with no value");
+			BarryLogf(TRACE_INTERNAL, _("ENCODING parameter added with no value"));
 		}
 	}
 }
@@ -1755,7 +1756,7 @@ b_vformat_attribute_get_value (b_VFormatAttribute *attr)
 	values = b_vformat_attribute_get_values (attr);
 
 	if (!b_vformat_attribute_is_single_valued (attr))
-		BarryLogf(TRACE_INTERNAL, "b_vformat_attribute_get_value called on multivalued attribute");
+		BarryLogf(TRACE_INTERNAL, _("b_vformat_attribute_get_value called on multivalued attribute"));
 
 	return values ? g_strdup ((char*)values->data) : NULL;
 }
@@ -1771,7 +1772,7 @@ b_vformat_attribute_get_value_decoded (b_VFormatAttribute *attr)
 	values = b_vformat_attribute_get_values_decoded (attr);
 
 	if (!b_vformat_attribute_is_single_valued (attr))
-		BarryLogf(TRACE_INTERNAL, "b_vformat_attribute_get_value_decoded called on multivalued attribute");
+		BarryLogf(TRACE_INTERNAL, _("b_vformat_attribute_get_value_decoded called on multivalued attribute"));
 
 	if (values)
 		str = values->data;
