@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2008-2009, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2008-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@
 
 #include <barry/barry.h>
 #include <sstream>
-#include <getopt.h>
 #include <vector>
 #include <list>
 #include <string>
@@ -36,6 +35,10 @@
 #include <sys/types.h>
 #include <fcntl.h>
 #include <string.h>
+#include <stdlib.h>
+#include "i18n.h"
+
+#include "barrygetopt.h"
 
 using namespace std;
 using namespace std::tr1;
@@ -61,24 +64,24 @@ string cmdline_password;
 
 void Blurb()
 {
-   int major, minor;
-   const char *Version = Barry::Version(major, minor);
+   int logical, major, minor;
+   const char *Version = Barry::Version(logical, major, minor);
 
-   cerr
-   << "bfuse - FUSE filesystem for Blackberry databases\n"
-   << "        Copyright 2008-2009, Net Direct Inc. (http://www.netdirect.ca/)\n"
-   << "        Using: " << Version << "\n"
+   cerr << string_vprintf(
+   _("bfuse - FUSE filesystem for Blackberry databases\n"
+   "        Copyright 2008-2013, Net Direct Inc. (http://www.netdirect.ca/)\n"
+   "        Using: %s\n"), Version)
    << endl;
 }
 
 void Usage()
 {
-   cerr
-   << "\n"
-   << "Barry specific options:\n"
-   << "   -p pin    PIN of device to talk with\n"
-   << "             If only one device is plugged in, this flag is optional\n"
-   << "   -P pass   Simplistic method to specify device password\n"
+   cerr <<
+   _("\n"
+   "Barry specific options:\n"
+   "   -p pin    PIN of device to talk with\n"
+   "             If only one device is plugged in, this flag is optional\n"
+   "   -P pass   Simplistic method to specify device password\n")
    << endl;
 /*
    << "   -d db     Specify which database to mount.  If no -d options exist\n"
@@ -118,24 +121,14 @@ public:
 	{
 	}
 
-	virtual void Clear() {}
-
-	virtual void SetIds(uint8_t RecType, uint32_t UniqueId)
+	virtual void ParseRecord(const Barry::DBData &data,
+				 const Barry::IConverter *ic)
 	{
-		m_id = UniqueId;
-	}
-
-	virtual void ParseHeader(const Barry::Data &, size_t &) {}
-
-	virtual void ParseFields(const Barry::Data &data, size_t &offset,
-				const Barry::IConverter *ic)
-	{
-		m_os << "Raw record dump for record: "
+		m_id = data.GetUniqueId();
+		m_os << _("Raw record dump for record: ")
 			<< std::hex << m_id << std::endl;
-		m_os << data << std::endl;
+		m_os << data.GetData() << std::endl;
 	}
-
-	virtual void Store() {}
 };
 
 template <class Record>
@@ -179,6 +172,11 @@ ParserPtr GetParser(const string &name, std::ostream &os, bool null_parser)
 			new RecordParser<Calendar, Store<Calendar> > (
 				new Store<Calendar>(os)));
 	}
+	else if( name == CalendarAll::GetDBName() ) {
+		return ParserPtr(
+			new RecordParser<CalendarAll, Store<CalendarAll> > (
+				new Store<CalendarAll>(os)));
+	}
 	else if( name == ServiceBook::GetDBName() ) {
 		return ParserPtr(
 			new RecordParser<ServiceBook, Store<ServiceBook> > (
@@ -210,10 +208,10 @@ ParserPtr GetParser(const string &name, std::ostream &os, bool null_parser)
 			new RecordParser<Folder, Store<Folder> > (
 				new Store<Folder>(os)));
 	}
-	else if( name == Timezone::GetDBName() ) {
+	else if( name == TimeZone::GetDBName() ) {
 		return ParserPtr(
-			new RecordParser<Timezone, Store<Timezone> > (
-				new Store<Timezone>(os)));
+			new RecordParser<TimeZone, Store<TimeZone> > (
+				new Store<TimeZone>(os)));
 	}
 	else {
 		// unknown database, use null parser
@@ -433,7 +431,7 @@ public:
 		string constructed = string("/") + ps.Pin() + "/" + ps.DB();
 		if( constructed != m_name ) {
 			// FIXME - this is shoddy error handling
-			throw std::logic_error("Constructed != name");
+			throw std::logic_error(_("Constructed != name"));
 		}
 
 		string data = GetRecordData(ps.Record());
@@ -451,13 +449,13 @@ public:
 		string constructed = string("/") + ps.Pin() + "/" + ps.DB();
 		if( constructed != m_name ) {
 			// FIXME - this is shoddy error handling
-			throw std::logic_error("Constructed != name");
+			throw std::logic_error(_("Constructed != name"));
 		}
 
 		string data = GetRecordData(ps.Record());
 
 		size_t len = data.size();
-		if( offset < len ) {
+		if( offset >= 0 && offset < (off_t)len ) {
 			if( (offset + size) > len )
 				size = len - offset;
 			memcpy(buf, data.data() + offset, size);
@@ -570,7 +568,7 @@ public:
 		g_dirmap["/"] = this;
 		g_filemap[string("/") + error_log_filename] = this;
 
-		m_error_log = "Hello FUSE world.  This is Barry.  Pleased to meet you.\n";
+		m_error_log = _("Hello FUSE world.  This is Barry.  Pleased to meet you.\n");
 	}
 
 	~Context()
@@ -603,7 +601,7 @@ public:
 	virtual int ReadFile(const char *path, char *buf, size_t size, off_t offset)
 	{
 		size_t len = m_error_log.size();
-		if( offset < len ) {
+		if( offset >= 0 && offset < (off_t)len ) {
 			if( (offset + size) > len )
 				size = len - offset;
 			memcpy(buf, m_error_log.data() + offset, size);
@@ -629,23 +627,22 @@ public:
 
 		// connect to all PINs found, and add them to our map
 		for( int i = 0; i < m_probe->GetCount(); i++ ) {
-			ostringstream oss;
-			oss << hex << m_probe->Get(i).m_pin;
+			string curpin = m_probe->Get(i).m_pin.Str();
 
 			// don't add a blank or pre-existing pin
-			if( !oss.str().size() || m_pinmap.find(oss.str()) != m_pinmap.end() ) {
+			if( !curpin.size() || m_pinmap.find(curpin) != m_pinmap.end() ) {
 				continue;
 			}
 
 			// don't add non-PIN device if pin specified
-			if( m_limit_pin.size() && oss.str() != m_limit_pin ) {
+			if( m_limit_pin.size() && curpin != m_limit_pin ) {
 				continue;
 			}
 
 			DesktopConPtr dev = DesktopConPtr (
-				new DesktopCon(m_probe->Get(i), oss.str()) );
+				new DesktopCon(m_probe->Get(i), curpin) );
 			dev->Open(m_password.c_str());
-			m_pinmap[ oss.str() ] = dev;
+			m_pinmap[ curpin ] = dev;
 		}
 	}
 
@@ -745,6 +742,8 @@ static struct fuse_operations bfuse_oper;
 
 int main(int argc, char *argv[])
 {
+	INIT_I18N(PACKAGE);
+
 	cout.sync_with_stdio(true);	// leave this on, since libusb uses
 					// stdio for debug messages
 
