@@ -5,7 +5,7 @@
 ///
 
 /*
-    Copyright (C) 2008-2009, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2008-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,83 +25,40 @@
 #include <iostream>
 #include <vector>
 #include <string>
-#include <getopt.h>
+#include <stdlib.h>
+#include "i18n.h"
+#include "brecsum.h"
+#include "barrygetopt.h"
 
 using namespace std;
 using namespace Barry;
 
 void Usage()
 {
-   int major, minor;
-   const char *Version = Barry::Version(major, minor);
+   int logical, major, minor;
+   const char *Version = Barry::Version(logical, major, minor);
 
-   cerr
-   << "brecsum - Generate SHA1 sums of raw Blackberry database records.\n"
-   << "        Copyright 2008-2009, Net Direct Inc. (http://www.netdirect.ca/)\n"
-   << "        Using: " << Version << "\n"
-   << "\n"
-   << "   -d db     Read database 'db' and sum all its records.\n"
-   << "             Can be used multiple times to fetch more than one DB\n"
-   << "   -h        This help\n"
-   << "   -i        Include Type and Unique record IDs in the checksums\n"
-   << "   -p pin    PIN of device to talk with\n"
-   << "             If only one device is plugged in, this flag is optional\n"
-   << "   -P pass   Simplistic method to specify device password\n"
-   << "   -v        Dump protocol data during operation\n"
+   cerr << string_vprintf(
+   _("brecsum - Generate SHA1 sums of raw Blackberry database records.\n"
+   "        Copyright 2008-2013, Net Direct Inc. (http://www.netdirect.ca/)\n"
+   "        Using: %s\n"
+   "\n"
+   "   -d db     Read database 'db' and sum all its records.\n"
+   "             Can be used multiple times to fetch more than one DB\n"
+   "   -h        This help\n"
+   "   -i        Include DB Name, Type, and Unique record IDs in the checksums\n"
+   "   -p pin    PIN of device to talk with\n"
+   "             If only one device is plugged in, this flag is optional\n"
+   "   -P pass   Simplistic method to specify device password\n"
+   "   -v        Dump protocol data during operation\n"),
+	Version)
    << endl;
 }
 
-class ChecksumParser : public Barry::Parser
-{
-	bool m_IncludeIds;
-	SHA_CTX m_ctx;
-
-public:
-	explicit ChecksumParser(bool IncludeIds)
-		: m_IncludeIds(IncludeIds)
-	{}
-
-	virtual void Clear()
-	{
-		SHA1_Init(&m_ctx);
-	}
-
-	virtual void SetIds(uint8_t RecType, uint32_t UniqueId)
-	{
-		if( m_IncludeIds ) {
-			SHA1_Update(&m_ctx, &RecType, sizeof(RecType));
-			SHA1_Update(&m_ctx, &UniqueId, sizeof(UniqueId));
-		}
-	}
-
-	virtual void ParseHeader(const Barry::Data &, size_t &)
-	{
-		// do nothing here, parse it all at once in ParseFields
-	}
-
-	virtual void ParseFields(const Barry::Data &data, size_t &offset,
-				const Barry::IConverter *ic)
-	{
-		int len = data.GetSize() - offset;
-		SHA1_Update(&m_ctx, data.GetData() + offset, len);
-		offset += len;
-	}
-
-	virtual void Store()
-	{
-		unsigned char sha1[SHA_DIGEST_LENGTH];
-		SHA1_Final(sha1, &m_ctx);
-
-		for( int i = 0; i < SHA_DIGEST_LENGTH; i++ ) {
-			cout << hex << setfill('0') << setw(2)
-				<< (unsigned int) sha1[i];
-		}
-		cout << endl;
-	}
-};
-
 int main(int argc, char *argv[])
 {
+	INIT_I18N(PACKAGE);
+
 	cout.sync_with_stdio(true);	// leave this on, since libusb uses
 					// stdio for debug messages
 
@@ -163,7 +120,8 @@ int main(int argc, char *argv[])
 		Barry::Probe probe;
 		int activeDevice = probe.FindActive(pin);
 		if( activeDevice == -1 ) {
-			cerr << "No device selected, or PIN not found" << endl;
+			cerr << _("No device selected, or PIN not found")
+				<< endl;
 			return 1;
 		}
 
