@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2008-2009, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2008-2013, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,7 +19,10 @@
     root directory of this project for more details.
 */
 
-#define __BARRY_BOOST_MODE__	// this program always requires BOOST
+// Boost is required, but since the real Boost serialization code is in
+// util.cc, we don't need it here.
+#undef __BARRY_BOOST_MODE__
+
 #include <barry/barry.h>
 #include <iomanip>
 #include <iostream>
@@ -28,40 +31,49 @@
 #include <vector>
 #include <string>
 #include <algorithm>
-#include <getopt.h>
+#include "i18n.h"
 
+#include "barrygetopt.h"
+#include "util.h"
+#include "boostwrap.h"
 
 using namespace std;
 using namespace Barry;
 
 void Usage()
 {
-   int major, minor;
-   const char *Version = Barry::Version(major, minor);
+   int logical, major, minor;
+   const char *Version = Barry::Version(logical, major, minor);
 
-   cerr
-   << "bs11nread - Reads a boost serialization file (from btool)\n"
-   << "            and dumps data to stdout\n"
-   << "        Copyright 2008-2009, Net Direct Inc. (http://www.netdirect.ca/)\n"
-   << "        Using: " << Version << "\n"
-   << "\n"
-   << "   -f file   Filename to save or load handheld data to/from\n"
-   << "   -h        This help\n"
-   << "   -S        Show list of supported database parsers\n"
+   cerr << string_vprintf(
+   _("bs11nread - Reads a boost serialization file (from btool)\n"
+   "            and dumps data to stdout\n"
+   "        Copyright 2008-2013, Net Direct Inc. (http://www.netdirect.ca/)\n"
+   "        Using: %s\n"
+   "\n"
+   "   -f file   Filename to save or load handheld data to/from\n"
+   "   -h        This help\n"
+   "   -S        Show list of supported database parsers\n"),
+	Version)
    << endl;
 }
 
 template <class Record>
-bool Dump(const std::string &dbName, ifstream &ifs)
+bool Dump(const std::string &dbName, const std::string &filename)
 {
 	if( dbName != Record::GetDBName() )
 		return false;
 
 	std::vector<Record> records;
-	boost::archive::text_iarchive ia(ifs);
-	ia >> records;
+	std::string junk, errmsg;
+
+	if( !LoadBoostFile(filename, records, junk, errmsg) ) {
+		cerr << errmsg << endl;
+		return false;
+	}
+
 	cout << records.size()
-	     << " records loaded" << endl;
+	     << _(" records loaded") << endl;
 	sort(records.begin(), records.end());
 
 	typename std::vector<Record>::const_iterator
@@ -79,39 +91,19 @@ void DumpDB(const string &filename)
 	ifstream ifs(filename.c_str());
 	std::string dbName;
 	getline(ifs, dbName);
+	ifs.close();
 
 	// check for recognized database names
-	Dump<Contact>		(dbName, ifs) ||
-	Dump<Message>		(dbName, ifs) ||
-	Dump<Calendar>		(dbName, ifs) ||
-	Dump<ServiceBook>	(dbName, ifs) ||
-	Dump<Memo>		(dbName, ifs) ||
-	Dump<Task>		(dbName, ifs) ||
-	Dump<PINMessage>	(dbName, ifs) ||
-	Dump<SavedMessage>	(dbName, ifs) ||
-	Dump<Folder>		(dbName, ifs) ||
-	Dump<Timezone>		(dbName, ifs) ||
-		cerr << "Unknown database name: " << dbName << endl;
-}
-
-void ShowParsers()
-{
-	cout << "Supported Database parsers:\n"
-	<< "   Address Book\n"
-	<< "   Messages\n"
-	<< "   Calendar\n"
-	<< "   Service Book\n"
-	<< "   Memos\n"
-	<< "   Tasks\n"
-	<< "   PIN Messages\n"
-	<< "   Saved Email Messages\n"
-	<< "   Folders\n"
-	<< "   Time Zones\n"
-	<< endl;
+#undef HANDLE_PARSER
+#define HANDLE_PARSER(tname) Dump<tname>(dbName, filename) ||
+	ALL_KNOWN_PARSER_TYPES
+		cerr << _("Unknown database name: ") << dbName << endl;
 }
 
 int main(int argc, char *argv[])
 {
+	INIT_I18N(PACKAGE);
+
 	try {
 		string filename;
 
@@ -128,7 +120,7 @@ int main(int argc, char *argv[])
 				break;
 
 			case 'S':	// show supported databases
-				ShowParsers();
+				ShowParsers(false, false);
 				return 0;
 
 			case 'h':	// help
@@ -143,28 +135,23 @@ int main(int argc, char *argv[])
 		Barry::Init();
 
 		if( !filename.size() ) {
-			cerr << "Filename must be specified" << endl;
+			cerr << _("Filename must be specified") << endl;
 			return 1;
 		}
 
 		DumpDB(filename);
 
 	}
-	catch( boost::archive::archive_exception &ae ) {
-		cerr << "Archive exception: "
-		     << ae.what() << endl;
-		return 1;
-	}
 	catch( Usb::Error &ue) {
-		std::cerr << "Usb::Error caught: " << ue.what() << endl;
+		std::cerr << _("Usb::Error caught: ") << ue.what() << endl;
 		return 1;
 	}
 	catch( Barry::Error &se ) {
-		std::cerr << "Barry::Error caught: " << se.what() << endl;
+		std::cerr << _("Barry::Error caught: ") << se.what() << endl;
 		return 1;
 	}
 	catch( std::exception &e ) {
-		std::cerr << "std::exception caught: " << e.what() << endl;
+		std::cerr << _("std::exception caught: ") << e.what() << endl;
 		return 1;
 	}
 
